# SPDX-FileCopyrightText: Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
# SPDX-License-Identifier: BSD-3-Clause
from vtkmodules import vtkCommonCore as cc
from vtkmodules import vtkCommonDataModel as dm
from vtkmodules import vtkCommonExecutionModel as em
from vtkmodules import vtkImagingCore as ic
from vtkmodules import vtkInteractionStyle as ii
from vtkmodules import vtkIOCellGrid as io
from vtkmodules import vtkFiltersCellGrid as fc
from vtkmodules import vtkRenderingAnnotation as ra
from vtkmodules import vtkRenderingCore as rr
from vtkmodules import vtkRenderingCellGrid as rg
from vtkmodules import vtkInteractionWidgets as iw

import vtkmodules.vtkRenderingFreeType
import vtkmodules.vtkRenderingOpenGL2
from vtkmodules.util.vtkAlgorithm import VTKPythonAlgorithmBase
from vtkmodules.util.misc import vtkGetDataRoot
VTK_DATA_ROOT = vtkGetDataRoot()

from vtkmodules.test import Testing
import os
import sys

# Register render responder for DG cells:
rg.vtkRenderingCellGrid.RegisterCellsAndResponders()

class Shortcuts:
    TOGGLE_PARAM_COORD_VIZ = 'c'
    TOGGLE_HELP_MENU = 'h'
    RESET = 'r'
    TOGGLE_HOVER_PRINT = 'v'
    TOGGLE_TESSELLATION = 't'

class CellGridInteractorStyle(ii.vtkInteractorStyleTrackballCamera):
    """
    Used to toggle visibility of parametric coordinate, tessellated geometry and show cell information under mouse.
    This interactor style adds capabilities that aid in debugging cell grid rendering. It effectively upgrades the unit test
    into a mini application to view cell grids.
    """

    def __init__(self, rw):
        self._toggles = dict()
        self._actions = dict()

        self._setup_help_menu()

        ren2D = rr.vtkRenderer()
        ren2D.EraseOff()
        ren2D.InteractiveOff()
        rw.AddRenderer(ren2D)

        self.shortcutActor = iw.vtkTextRepresentation()

        self.shortcutActor.SetText(self.get_shortcuts_as_string())
        self.shortcutActor.SetRenderer(ren2D)
        self.shortcutActor.BuildRepresentation()
        self.shortcutActor.SetPosition(0, 0.5)
        self.shortcutActor.GetTextActor().SetTextScaleModeToNone()
        self.shortcutActor.GetTextActor().GetTextProperty().SetBackgroundRGBA(0.1, 0.1, 0.1, 0.2)
        self.shortcutActor.SetShowBorder(True)
        self.shortcutActor.SetBorderColor(0.84313725, 0.75686275, 0.90980392)
        self.shortcutActor.SetCornerRadiusStrength(0.1)
        self.shortcutActor.SetPadding(4)
        self.shortcutActor.GetTextActor().GetTextProperty().SetFontFamilyToCourier()
        self.shortcutActor.GetTextActor().GetTextProperty().SetFontSize(18)
        self.shortcutActor.GetTextActor().GetTextProperty().SetJustificationToLeft()
        self.shortcutActor.SetVisibility(True)
        ren2D.AddActor(self.shortcutActor)

        rg.vtkDGRenderResponder.SetScalarVisualizationOverrideType(self.scalar_vis_types[0][1])
        rg.vtkDGRenderResponder.SetVisualizeTessellation(False)

        self.AddObserver("KeyPressEvent", self.onKeyPress)
        self.AddObserver("MouseMoveEvent", self.onMouseMove)

        self.hoveredCellInfoActor = rr.vtkTextActor()
        self.hoveredCellInfoActor.SetTextScaleModeToNone()
        self.hoveredCellInfoActor.GetTextProperty().SetFontSize(24)
        self.hoveredCellInfoActor.GetTextProperty().SetColor(1, 1, 0)
        ren2D.AddActor(self.hoveredCellInfoActor)

    def _setup_help_menu(self):
        toggle_switch_stringifier = lambda v: "On/Off" if v else "Off/Off"
        self.add_toggle(Shortcuts.TOGGLE_PARAM_COORD_VIZ, "Color by parametric coord.", 0, value_to_str_fn=lambda i: self.scalar_vis_types[i][0])
        self.add_toggle(Shortcuts.TOGGLE_HELP_MENU, "Show/Hide this help menu", True, value_to_str_fn=toggle_switch_stringifier)
        self.add_action(Shortcuts.RESET, "Reset")
        self.add_toggle(Shortcuts.TOGGLE_HOVER_PRINT, "Show/Hide information on hover", False, value_to_str_fn=toggle_switch_stringifier)
        self.add_toggle(Shortcuts.TOGGLE_TESSELLATION, "Show/Hide tessellation", False, value_to_str_fn=toggle_switch_stringifier)

    def add_action(self, key: str, doc: str):
        self._actions.update({key: doc})

    def add_toggle(self, key: str, doc: str, current_value, value_to_str_fn = str):
        self._toggles.update({key: [doc, current_value, value_to_str_fn]})

    def get_toggle_value(self, key: str):
        return self._toggles.get(key)[1]

    def set_toggle_value(self, key: str, value):
        self._toggles.get(key)[1] = value

    def get_shortcuts_as_string(self):
        result = ""
        for key, doc in self._actions.items():
            result += f"{key}: {doc}\n"
        for key, (doc, current, value_to_str_fn) in self._toggles.items():
            result += f"{key}: {doc} [{value_to_str_fn(current)}] \n"
        return result

    @property
    def scalar_vis_types(self):
        return (
            ("NONE", rg.vtkDGRenderResponder.ScalarVisualizationOverrideType.NONE),
            ("R", rg.vtkDGRenderResponder.ScalarVisualizationOverrideType.R),
            ("S", rg.vtkDGRenderResponder.ScalarVisualizationOverrideType.S),
            ("T", rg.vtkDGRenderResponder.ScalarVisualizationOverrideType.T),
            ("L2_NORM_R_S", rg.vtkDGRenderResponder.ScalarVisualizationOverrideType.L2_NORM_R_S),
            ("L2_NORM_S_T", rg.vtkDGRenderResponder.ScalarVisualizationOverrideType.L2_NORM_S_T),
            ("L2_NORM_T_R", rg.vtkDGRenderResponder.ScalarVisualizationOverrideType.L2_NORM_T_R),
        )

    def onMouseMove(self, obj, event):
        interactor = obj.GetInteractor()
        if not self.get_toggle_value(Shortcuts.TOGGLE_HOVER_PRINT):
            self.hoveredCellInfoActor.SetVisibility(False)
            interactor.GetInteractorStyle().OnMouseMove()
            interactor.Render()
            return
        cursor = interactor.GetEventPosition()
        renderer = interactor.FindPokedRenderer(cursor[0], cursor[1])
        selection = dm.vtkSelection()
        renderer.PickProp(cursor[0], cursor[1], 0, selection)
        showInfoText = False
        for i in range(selection.GetNumberOfNodes()):
            node = selection.GetNode(i)
            properties = node.GetProperties()
            selectedIds = node.GetSelectionData().GetArray(0)
            mapper = properties.Get(dm.vtkSelectionNode.PROP()).GetMapper()
            if not isinstance(mapper, rr.vtkCellGridMapper):
                continue
            showInfoText = True
            cellTypes = mapper.GetInputDataObject(0, 0).GetCellTypes()
            cellTypeIdx = properties.Get(dm.vtkSelectionNode.CELLGRID_CELL_TYPE_INDEX())
            caption = f"CELL_TYPE={cellTypes[cellTypeIdx]}\n" +\
                f"CELLGRID_SOURCE_SPECIFICATION_INDEX={properties.Get(dm.vtkSelectionNode.CELLGRID_SOURCE_SPECIFICATION_INDEX())}\n" +\
                f"CELLGRID_CELL_TYPE_INDEX={properties.Get(dm.vtkSelectionNode.CELLGRID_CELL_TYPE_INDEX())}\n" +\
                f"selected_ids={[int(selectedIds.GetValue(i)) for i in range(selectedIds.GetNumberOfValues())]}"
            self.hoveredCellInfoActor.SetInput(caption)
            self.hoveredCellInfoActor.SetDisplayPosition(cursor[0], cursor[1])

        self.hoveredCellInfoActor.SetVisibility(showInfoText)
        interactor.Render()
        interactor.GetInteractorStyle().OnMouseMove()

    def onKeyPress(self, obj, event):
        interactor = obj.GetInteractor()
        key = interactor.GetKeySym().lower()
        if key == Shortcuts.TOGGLE_PARAM_COORD_VIZ:
            self.set_toggle_value(key, (self.get_toggle_value(key) + 1) % len(self.scalar_vis_types))
        elif key == Shortcuts.TOGGLE_HELP_MENU or key == Shortcuts.TOGGLE_HOVER_PRINT or key == Shortcuts.TOGGLE_TESSELLATION:
            self.set_toggle_value(key, not self.get_toggle_value(key))
        elif key == Shortcuts.RESET:
            self.set_toggle_value(Shortcuts.TOGGLE_PARAM_COORD_VIZ, 0)
            self.set_toggle_value(Shortcuts.TOGGLE_TESSELLATION, False)
        vis_type = self.scalar_vis_types[self.get_toggle_value(Shortcuts.TOGGLE_PARAM_COORD_VIZ)][1]
        rg.vtkDGRenderResponder.SetScalarVisualizationOverrideType(vis_type)
        rg.vtkDGRenderResponder.SetVisualizeTessellation(self.get_toggle_value(Shortcuts.TOGGLE_TESSELLATION))
        self.shortcutActor.SetVisibility(self.get_toggle_value(Shortcuts.TOGGLE_HELP_MENU))
        self.shortcutActor.SetText(self.get_shortcuts_as_string())
        interactor.Render()


class TestCellGridRendering(Testing.vtkTest):

    def runCase(self, dataFile, colorArray, imageFile, cell2D = False, angles = (0, 0, 0), colorArrayComponent=-2):
        rh = io.vtkCellGridReader()
        rh.SetFileName(dataFile)
        fh = fc.vtkCellGridComputeSides()
        fh.SetInputConnection(rh.GetOutputPort())
        fh.SetOutputDimensionControl(dm.vtkCellGridSidesQuery.NextLowestDimension)
        fh.PreserveRenderableInputsOff()
        fh.OmitSidesForRenderableInputsOff()
        fh.Update()
        surfOut = fh.GetOutputDataObject(0)
        # Note: For 2-d cells, we create 2 actor/mapper pairs:
        # + one (ai, mi) to show the original cells
        # + one (ah, mh) to show the edge-sides of the surface
        #   manifold (only those edge-sides on the boundary of the mesh).
        # We use separate mappers so the edges can be rendered without
        # scalar coloring.
        if cell2D:
            ah = rr.vtkActor()
            mh = rr.vtkCellGridMapper()
            mh.SetInputConnection(fh.GetOutputPort())
            ah.SetMapper(mh)
            ah.GetProperty().SetLineWidth(4.0)
        ai = rr.vtkActor()
        mi = rr.vtkCellGridMapper()
        if cell2D:
            mi.SetInputConnection(rh.GetOutputPort())
        else:
            mi.SetInputConnection(fh.GetOutputPort())
        if colorArray != None:
            #if cell2D:
            #    mh.ScalarVisibilityOn()
            #    mh.SetScalarMode(rr.VTK_SCALAR_MODE_USE_CELL_FIELD_DATA)
            #    mh.SetArrayName(colorArray)
            #    if colorArrayComponent != 0:
            #        mh.SetArrayComponent(colorArrayComponent)
            mi.ScalarVisibilityOn()
            mi.SetScalarMode(rr.VTK_SCALAR_MODE_USE_CELL_FIELD_DATA)
            mi.SetArrayName(colorArray)
            mi.SetArrayComponent(colorArrayComponent)
            gg = rh.GetOutputDataObject(0)
            arange = [0, 0]
            gg.GetCellAttributeRange(gg.GetCellAttributeByName(colorArray), colorArrayComponent, arange, True)
            print('test says color range', colorArray, colorArrayComponent, arange)
            # mi.SetScalarRange(*arange)
            mi.SetUseLookupTableScalarRange(0)
            # mi.UseLookupTableScalarRangeOff()
        ai.SetMapper(mi)
        rw = rr.vtkRenderWindow()
        rn = rr.vtkRenderer()
        ri = rw.MakeRenderWindowInteractor()
        ow = iw.vtkCameraOrientationWidget()
        rw.SetInteractor(ri)
        rw.AddRenderer(rn)
        rw.SetWindowName(imageFile.replace("TestCellGridRendering-", "").replace(".png", ""))
        rn.AddActor(ai)
        ow.SetParentRenderer(rn)
        ow.On()
        if cell2D:
            rn.AddActor(ah)
        rn.GetActiveCamera().Roll(angles[0])
        rn.GetActiveCamera().Azimuth(angles[1])
        rn.GetActiveCamera().Elevation(angles[2])
        rn.ResetCamera()
        rw.SetSize(300, 300)
        rw.Render()
        if "-I" in sys.argv:
            rw.SetSize(1920, 1080)
            rs = CellGridInteractorStyle(rw)
            ri.SetInteractorStyle(rs)

            # In interactive mode, it helps to visualize the point IDs for debugging purpose.
            if cell2D:
                inputData = rh.GetOutput()
            else:
                inputData = fh.GetOutput()
            points = inputData.FindAttributes("coordinates").GetArray(0)
            for i in range(points.GetNumberOfTuples()):
                point = points.GetTuple3(i)
                ca = ra.vtkCaptionActor2D()
                ca.SetAttachmentPoint(point)
                ca.SetCaption(f"{i}")
                ca.SetBorder(False)
                ca.GetTextActor().SetTextScaleModeToNone()
                ca.GetCaptionTextProperty().SetFontSize(12)
                ca.GetCaptionTextProperty().SetColor(1, 1, 0)
                rn.AddActor(ca)
            rw.Render()
            ri.Start()
        # else:
            # Testing.compareImage(rw, Testing.getAbsImagePath(imageFile))

    def testCurlVectorComponents(self):
        dataFile = os.path.join(VTK_DATA_ROOT, 'Data', 'dgHexahedra.dg')
        testFile = 'TestCellGridRendering-CurlX.png'
        self.runCase(dataFile, 'curl1', testFile, False, angles=(0, 180, -20), colorArrayComponent=0)
        dataFile = os.path.join(VTK_DATA_ROOT, 'Data', 'dgHexahedra.dg')
        testFile = 'TestCellGridRendering-CurlY.png'
        self.runCase(dataFile, 'curl1', testFile, False, angles=(0, 180, -20), colorArrayComponent=1)
        dataFile = os.path.join(VTK_DATA_ROOT, 'Data', 'dgHexahedra.dg')
        testFile = 'TestCellGridRendering-CurlZ.png'
        self.runCase(dataFile, 'curl1', testFile, False, angles=(0, 180, -20), colorArrayComponent=2)

    def testDivVectorComponents(self):
        dataFile = os.path.join(VTK_DATA_ROOT, 'Data', 'dgHexahedra.dg')
        testFile = 'TestCellGridRendering-DivX.png'
        self.runCase(dataFile, 'div1', testFile, False, angles=(0, 180, -20), colorArrayComponent=0)
        dataFile = os.path.join(VTK_DATA_ROOT, 'Data', 'dgHexahedra.dg')
        testFile = 'TestCellGridRendering-DivY.png'
        self.runCase(dataFile, 'div1', testFile, False, angles=(0, 180, -20), colorArrayComponent=1)
        dataFile = os.path.join(VTK_DATA_ROOT, 'Data', 'dgHexahedra.dg')
        testFile = 'TestCellGridRendering-DivZ.png'
        self.runCase(dataFile, 'div1', testFile, False, angles=(0, 180, -20), colorArrayComponent=2)

    def testDGWdgRendering(self):
        dataFile = os.path.join(VTK_DATA_ROOT, 'Data', 'dgWedges.dg')
        # Run once with cell coloring turned on:
        testFile = 'TestCellGridRendering-Wedges.png'
        self.runCase(dataFile, 'scalar1', testFile, False, angles=(15, -30, 10))

    def testDGPyrRendering(self):
        dataFile = os.path.join(VTK_DATA_ROOT, 'Data', 'dgPyramid19.dg')
        # Run once with cell coloring turned on:
        testFile = 'TestCellGridRendering-Pyramid19.png'
        self.runCase(dataFile, 'scalar3', testFile, False, angles=(-15, 20, -60))
        # Run once coloring by a solid color:
        testFile = 'TestCellGridRendering-Pyramid19-uncolored.png'
        self.runCase(dataFile, None, testFile, False, angles=(-10, 10, -30))

    def testDGHexRendering(self):
        dataFile = os.path.join(VTK_DATA_ROOT, 'Data', 'dgHexahedra.dg')
        # Run with HCurl coloring turned on:
        testFile = 'TestCellGridRendering-Hexahedra-curl1.png'
        self.runCase(dataFile, 'curl1', testFile, False, angles=(0, 180, -20), colorArrayComponent=2)
        # # Run once with cell coloring turned on:
        testFile = 'TestCellGridRendering-Hexahedra.png'
        self.runCase(dataFile, 'scalar1', testFile, False, angles=(10, 20, 30))
        # Run once coloring by a solid color:
        testFile = 'TestCellGridRendering-Hexahedra-uncolored.png'
        self.runCase(dataFile, None, testFile, False)
        # Run once with quadratic cell coloring turned on:
        testFile = 'TestCellGridRendering-Hexahedra-quadratic.png'
        self.runCase(dataFile, 'quadratic', testFile, False, angles=(10, 20, 30))

    def testDGTetRendering(self):
        dataFile = os.path.join(VTK_DATA_ROOT, 'Data', 'dgTetrahedra.dg')
        testFile = 'TestCellGridRendering-Tetrahedra.png'
        self.runCase(dataFile, 'scalar2', testFile, False, angles=(10, 20, 20))

    def testDGQuadRendering(self):
        dataFile = os.path.join(VTK_DATA_ROOT, 'Data', 'dgQuadrilateral.dg')
        testFile = 'TestCellGridRendering-Quadrilateral.png'
        self.runCase(dataFile, 'scalar1', testFile, True, angles=(10, 20, 30))
        dataFile = os.path.join(VTK_DATA_ROOT, 'Data', 'dgQuadraticQuadrilaterals.dg')
        testFile = 'TestCellGridRendering-Quadrilaterals-quadratic.png'
        self.runCase(dataFile, 'scalar2', testFile, True, angles=(10, -30, 0))

    def testDGTriRendering(self):
        dataFile = os.path.join(VTK_DATA_ROOT, 'Data', 'dgTriangle.dg')
        testFile = 'TestCellGridRendering-Triangles.png'
        self.runCase(dataFile, 'scalar1', testFile, True, angles=(10, 5, -30))

if __name__ == "__main__":
    Testing.main([(TestCellGridRendering, 'test')])



#!/usr/bin/env python
import sys
from vtkmodules.vtkFiltersCore import (
    vtkAppendPolyData,
    vtkDelaunay2D,
    vtkFeatureEdges,
    vtkPolyDataEdgeConnectivityFilter,
)
from vtkmodules.vtkFiltersSources import (
    vtkDiskSource,
    vtkPlaneSource,
)
from vtkmodules.vtkRenderingCore import (
    vtkActor,
    vtkPolyDataMapper,
    vtkRenderWindow,
    vtkRenderWindowInteractor,
    vtkRenderer,
)
import vtkmodules.vtkInteractionStyle
import vtkmodules.vtkRenderingFreeType
import vtkmodules.vtkRenderingOpenGL2
from vtkmodules.util.misc import vtkGetDataRoot
VTK_DATA_ROOT = vtkGetDataRoot()

# Test the vtkPolyDataEdgeConnectivityFilter, in particular
# barrier edges combined with sorted regions.

# Construct a bounding array of points to improve the
# tessellation process.
plane = vtkPlaneSource()
plane.SetResolution(10,10)
plane.SetOrigin(-5,-5,0)
plane.SetPoint1(5,-5,0)
plane.SetPoint2(-5,5,0)

# Remove interior points
pedges = vtkFeatureEdges()
pedges.SetInputConnection(plane.GetOutputPort())
pedges.ExtractAllEdgeTypesOff()
pedges.BoundaryEdgesOn()
pedges.Update()

# Create some points in concentric circles.
disk = vtkDiskSource()
disk.SetInnerRadius(0.5)
disk.SetOuterRadius(1.0)
disk.SetRadialResolution(1)
disk.SetCircumferentialResolution(32)
disk.Update()

# Create some points in concentric circles.
disk2 = vtkDiskSource()
disk2.SetInnerRadius(2.0)
disk2.SetOuterRadius(3.5)
disk2.SetRadialResolution(1)
disk2.SetCircumferentialResolution(64)
disk2.Update()

# Append plane points and disk points.
append = vtkAppendPolyData()
append.AddInputData(pedges.GetOutput())
append.AddInputData(disk.GetOutput())
append.AddInputData(disk2.GetOutput())
append.Update()

# Tessellate
tess = vtkDelaunay2D()
tess.SetInputConnection(append.GetOutputPort())
tess.Update()

# Color via connected regions
conn = vtkPolyDataEdgeConnectivityFilter()
conn.SetInputConnection(tess.GetOutputPort());
conn.BarrierEdgesOn()
conn.GrowSmallRegionsOn()
conn.SetBarrierEdgeLength(0.0,0.35)
conn.SetExtractionModeToAllRegions()
conn.SetLargeRegionThreshold(0.25)
conn.ColorRegionsOn()
conn.CellRegionAreasOn()
conn.Update()

tessMapper = vtkPolyDataMapper()
tessMapper.SetInputConnection(conn.GetOutputPort())
tessMapper.ScalarVisibilityOn()
tessMapper.SetScalarModeToUseCellData()
tessMapper.SetScalarRange(0,2)
print("Num cells: ",conn.GetOutput().GetNumberOfCells())
print("Num regions: ",conn.GetNumberOfExtractedRegions())

tessActor = vtkActor()
tessActor.SetMapper(tessMapper)
tessActor.GetProperty().SetColor(1,1,1)
tessActor.GetProperty().SetEdgeColor(0,0,0)

# Define graphics objects
ren1 = vtkRenderer()
ren1.SetBackground(0,0,0)
ren1.AddActor(tessActor)

renWin = vtkRenderWindow()
renWin.AddRenderer(ren1)

iren = vtkRenderWindowInteractor()
iren.SetRenderWindow(renWin)

iren.Initialize()
iren.Start()



#!/usr/bin/env python
from vtkmodules.vtkFiltersGeometry import vtkGeometryFilter
from vtkmodules.vtkIOEnSight import vtkGenericEnSightReader
from vtkmodules.vtkRenderingCore import (
    vtkActor,
    vtkCompositePolyDataMapper,
    vtkRenderWindow,
    vtkRenderWindowInteractor,
    vtkRenderer,
)
import vtkmodules.vtkInteractionStyle
import vtkmodules.vtkRenderingFreeType
import vtkmodules.vtkRenderingOpenGL2
from vtkmodules.util.misc import vtkGetDataRoot
VTK_DATA_ROOT = vtkGetDataRoot()

# create a rendering window and renderer
renderer = vtkRenderer()
renWin = vtkRenderWindow()
renWin.AddRenderer(renderer)
renWin.StereoCapableWindowOn()
iren = vtkRenderWindowInteractor()
iren.SetRenderWindow(renWin)

# create pipeline
reader = vtkGenericEnSightReader()
reader.SetCaseFileName(VTK_DATA_ROOT + "/Data/EnSight/viga.case")

geometry = vtkGeometryFilter()
geometry.SetInputConnection(reader.GetOutputPort())

mapper = vtkCompositePolyDataMapper()
mapper.SetInputConnection(geometry.GetOutputPort())

actor = vtkActor()
actor.SetMapper(mapper)

# render
renderer.AddActor(actor)
renWin.Render()



#!/usr/bin/env python
# -*- coding: utf-8 -*-
from vtkmodules.vtkCommonDataModel import (
    vtkPolyData,
    vtkSphericalPointIterator,
)
from vtkmodules.vtkFiltersSources import vtkPointSource
from vtkmodules.vtkRenderingCore import (
    vtkActor,
    vtkPolyDataMapper,
    vtkRenderWindow,
    vtkRenderWindowInteractor,
    vtkRenderer,
)
import vtkmodules.vtkInteractionStyle
import vtkmodules.vtkRenderingFreeType
import vtkmodules.vtkRenderingOpenGL2
from vtkmodules.vtkCommonCore import reference

# Test the generate of pre-defined vtkSphericalPointIterator axes sets.

# Generate a random point cloud as a placeholder
ps = vtkPointSource()
ps.SetNumberOfPoints(100)
ps.SetCenter(0,0,0)
ps.SetRadius(10)
ps.Update()

# Create several iterators with different axes sets

XY_CW_AXES = 0
pd0 = vtkPolyData()
pcenter = [0,0,0]
piter0 = vtkSphericalPointIterator()
piter0.SetDataSet(ps.GetOutput())
piter0.SetAxes(XY_CW_AXES,6)
piter0.SetSortTypeToNone()
piter0.Initialize(pcenter)
piter0.BuildRepresentation(pd0)

# Render the axes points
aMapper0 = vtkPolyDataMapper()
aMapper0.SetInputData(pd0)

aActor0 = vtkActor()
aActor0.SetMapper(aMapper0)
aActor0.GetProperty().SetColor(0.85,0.85,0.85)
aActor0.GetProperty().SetLineWidth(2)

XY_CCW_AXES = 1
pd1 = vtkPolyData()
pcenter = [2.5,0,0]
piter1 = vtkSphericalPointIterator()
piter1.SetDataSet(ps.GetOutput())
piter1.SetAxes(XY_CCW_AXES,6)
piter1.SetSortTypeToNone()
piter1.Initialize(pcenter)
piter1.BuildRepresentation(pd1)

# Render the axes points
aMapper1 = vtkPolyDataMapper()
aMapper1.SetInputData(pd1)

aActor1 = vtkActor()
aActor1.SetMapper(aMapper1)
aActor1.GetProperty().SetColor(0.85,0.85,0.85)
aActor1.GetProperty().SetLineWidth(2)

XY_SQUARE_AXES = 2
pd2 = vtkPolyData()
pcenter = [5,0,0]
piter2 = vtkSphericalPointIterator()
piter2.SetDataSet(ps.GetOutput())
piter2.SetAxes(XY_SQUARE_AXES)
piter2.SetSortTypeToNone()
piter2.Initialize(pcenter)
piter2.BuildRepresentation(pd2)

# Render the axes points
aMapper2 = vtkPolyDataMapper()
aMapper2.SetInputData(pd2)

aActor2 = vtkActor()
aActor2.SetMapper(aMapper2)
aActor2.GetProperty().SetColor(0.85,0.85,0.85)
aActor2.GetProperty().SetLineWidth(2)

CUBE_AXES = 3
pd3 = vtkPolyData()
pcenter = [7.5,0,0]
piter3 = vtkSphericalPointIterator()
piter3.SetDataSet(ps.GetOutput())
piter3.SetAxes(CUBE_AXES)
piter3.SetSortTypeToNone()
piter3.Initialize(pcenter)
piter3.BuildRepresentation(pd3)

# Render the axes points
aMapper3 = vtkPolyDataMapper()
aMapper3.SetInputData(pd3)

aActor3 = vtkActor()
aActor3.SetMapper(aMapper3)
aActor3.GetProperty().SetColor(0.85,0.85,0.85)
aActor3.GetProperty().SetLineWidth(2)

OCTAHEDRON_AXES = 4
pd4 = vtkPolyData()
pcenter = [0,2.5,0]
piter4 = vtkSphericalPointIterator()
piter4.SetDataSet(ps.GetOutput())
piter4.SetAxes(OCTAHEDRON_AXES)
piter4.SetSortTypeToNone()
piter4.Initialize(pcenter)
piter4.BuildRepresentation(pd4)

# Render the axes points
aMapper4 = vtkPolyDataMapper()
aMapper4.SetInputData(pd4)

aActor4 = vtkActor()
aActor4.SetMapper(aMapper4)
aActor4.GetProperty().SetColor(0.85,0.85,0.85)
aActor4.GetProperty().SetLineWidth(2)

CUBE_OCTAHEDRON_AXES = 5
pd5 = vtkPolyData()
pcenter = [2.5,2.5,0]
piter5 = vtkSphericalPointIterator()
piter5.SetDataSet(ps.GetOutput())
piter5.SetAxes(CUBE_OCTAHEDRON_AXES)
piter5.SetSortTypeToNone()
piter5.Initialize(pcenter)
piter5.BuildRepresentation(pd5)

# Render the axes points
aMapper5 = vtkPolyDataMapper()
aMapper5.SetInputData(pd5)

aActor5 = vtkActor()
aActor5.SetMapper(aMapper5)
aActor5.GetProperty().SetColor(0.85,0.85,0.85)
aActor5.GetProperty().SetLineWidth(2)

DODECAHEDRON_AXES = 6
pd6 = vtkPolyData()
pcenter = [5,2.5,0]
piter6 = vtkSphericalPointIterator()
piter6.SetDataSet(ps.GetOutput())
piter6.SetAxes(DODECAHEDRON_AXES)
piter6.SetSortTypeToNone()
piter6.Initialize(pcenter)
piter6.BuildRepresentation(pd6)

# Render the axes points
aMapper6 = vtkPolyDataMapper()
aMapper6.SetInputData(pd6)

aActor6 = vtkActor()
aActor6.SetMapper(aMapper6)
aActor6.GetProperty().SetColor(0.85,0.85,0.85)
aActor6.GetProperty().SetLineWidth(2)

ICOSAHEDRON_AXES = 7
pd7 = vtkPolyData()
pcenter = [7.5,2.5,0]
piter7 = vtkSphericalPointIterator()
piter7.SetDataSet(ps.GetOutput())
piter7.SetAxes(ICOSAHEDRON_AXES)
piter7.SetSortTypeToNone()
piter7.Initialize(pcenter)
piter7.BuildRepresentation(pd7)

# Render the axes points
aMapper7 = vtkPolyDataMapper()
aMapper7.SetInputData(pd7)

aActor7 = vtkActor()
aActor7.SetMapper(aMapper7)
aActor7.GetProperty().SetColor(0.85,0.85,0.85)
aActor7.GetProperty().SetLineWidth(2)

# Create the RenderWindow, Renderer and both Actors
#
ren0 = vtkRenderer()
renWin = vtkRenderWindow()
renWin.AddRenderer(ren0)

iRen = vtkRenderWindowInteractor()
iRen.SetRenderWindow(renWin)

# Add the actors to the renderer, set the background and size
#
ren0.AddActor(aActor0)
ren0.AddActor(aActor1)
ren0.AddActor(aActor2)
ren0.AddActor(aActor3)
ren0.AddActor(aActor4)
ren0.AddActor(aActor5)
ren0.AddActor(aActor6)
ren0.AddActor(aActor7)
ren0.GetActiveCamera().SetFocalPoint(1.25,3.75,0)
ren0.GetActiveCamera().SetPosition(1.45,3.85,.4)

renWin.SetSize(400, 200)

iRen.Initialize()
ren0.ResetCamera()
ren0.GetActiveCamera().Zoom(1.65)
renWin.Render()

# Interact with the data
iRen.Start()



from vtkmodules.vtkCommonCore import (
    vtkPoints,
    reference,
)
from vtkmodules.vtkCommonDataModel import (
    vtkHexahedron,
    vtkPyramid,
    vtkQuadraticHexahedron,
    vtkQuadraticPyramid,
    vtkQuadraticTetra,
    vtkQuadraticWedge,
    vtkTetra,
    vtkWedge,
)
import sys

# all values should be between 0 and 1
def WithinTol(a, b):
    for i in range(3):
        if abs(a[i] - b[i]) > 0.001:
            return False
    return True

def CheckTetra(success, x, pcoords):
    if x[0] >= 0. and x[0] <= 1.0 and x[1] >= 0. and x[1] <= 1.0 and x[2] >= 0. and x[2] <= 1.0 and x[0]+x[1]+x[2] < 1.01:
        if success != 1:
            print("should have found point ", x, " but did not")
            return False
        elif not WithinTol(x, pcoords):
            print("Parametric inversion failed for ", x, " with value of ", pcoords)
            return False
    else:
        if success == 1:
            print("should NOT have found point ", x, " but did. pcoords is ", pcoords)
            return False
    return True

def CheckHex(success, x, pcoords):
    if x[0] >= 0. and x[0] <= 1.0 and x[1] >= 0. and x[1] <= 1.0 and x[2] >= 0. and x[2] <= 1.0:
        if success != 1:
            print("should have found point ", x, " but did not")
            return False
        elif not WithinTol(x, pcoords):
            print("Parametric inversion failed for ", x, " with value of ", pcoords)
            return False
    else:
        if success == 1:
            print("should NOT have found point ", x, " but did. pcoords is ", pcoords)
            return False
    return True

def CheckPyramid(success, x, pcoords):
    # pcoords not in same coordinate space as x to we shrink it back down
    pcoords2 = [pcoords[0]*(1.-pcoords[2]), pcoords[1]*(1.-pcoords[2]), pcoords[2]]
    if x[0] >= 0. and x[0] <= 1.0-x[2] and x[1] >= 0. and x[1] <= 1.0-x[2] and x[2] >= 0. and x[2] <= 1.0:
        if success != 1:
            print("should have found point ", x, " but did not")
            return False
        elif not WithinTol(x, pcoords2):
            print("Parametric inversion failed for ", x, " with value of ", pcoords2)
            return False
    else:
        if success == 1:
            print("should NOT have found point ", x, " but did. pcoords is ", pcoords2)
            return False
    return True

def CheckWedge(success, x, pcoords):
    # wedge is a bit weird in that the normal of the bottom face (points 0, 1 and 2) using the right-hand rule
    # points away from the top face instead of towards it like the tet does.
    pcoords2 = [pcoords[1], pcoords[0], pcoords[2]]
    if x[0] >= 0. and x[0] <= 1.0 and x[1] >= 0. and x[1] <= 1.0 and x[2] >= 0. and x[2] <= 1.0 and x[0]+x[1] < 1.0001:
        if success != 1:
            print("should have found point ", x, " but did not")
            return False
        elif not WithinTol(x, pcoords2):
            print("Parametric inversion failed for ", x, " with value of ", pcoords2)
            return False
    else:
        if success == 1:
            print("should NOT have found point ", x, " but did. pcoords is ", pcoords2)
            return False
    return True

def CheckCell(cell, checkCellFunction):
    closestPoint = [0., 0., 0.]
    subId = reference(0)
    pcoords = [0., 0., 0.]
    dist2 = reference(0.)
    weights = [0.]*30
    x = [.25, .25, .25]
    for i in range(21):
        x[0] = -1.+3.*i/20.
        for j in range(21):
            x[1] = -1.+3.*j/20.
            for k in range(21):
                x[2] = -1.+3.*k/20.
                success = c.EvaluatePosition(x, closestPoint, subId, pcoords, dist2, weights)
                if not checkCellFunction(success, x, pcoords):
                    return False
    return True

pts = vtkPoints()
pts.SetNumberOfPoints(20) # quadratic hex has the most points with 20

# check Tets
pts.SetPoint(0, 0, 0, 0)
pts.SetPoint(1, 1, 0, 0)
pts.SetPoint(2, 0, 1, 0)
pts.SetPoint(3, 0, 0, 1)
pts.SetPoint(4, 0.5, 0, 0)
pts.SetPoint(5, 0.5, 0.5, 0)
pts.SetPoint(6, 0, 0.5, 0)
pts.SetPoint(7, 0, 0, 0.5)
pts.SetPoint(8, 0.5, 0, 0.5)
pts.SetPoint(9, 0., 0.5, 0.5)

c = vtkTetra()
c.Initialize(4, pts)
if not CheckCell(c, CheckTetra):
    print("Failure for vtkTetra")
    sys.exit(1)

c = vtkQuadraticTetra()
c.Initialize(10, pts)
if not CheckCell(c, CheckTetra):
    print("Failure for vtkQuadraticTetra")
    sys.exit(1)

# check hexes
pts.SetPoint(0, 0, 0, 0)
pts.SetPoint(1, 1, 0, 0)
pts.SetPoint(2, 1, 1, 0)
pts.SetPoint(3, 0, 1, 0)
pts.SetPoint(4, 0, 0, 1)
pts.SetPoint(5, 1, 0, 1)
pts.SetPoint(6, 1, 1, 1)
pts.SetPoint(7, 0, 1, 1)
pts.SetPoint(8, .5, 0, 0)
pts.SetPoint(9, 1, .5, 0)
pts.SetPoint(10, .5, 1, 0)
pts.SetPoint(11, 0, .5, 0)
pts.SetPoint(12, .5, 0, 1)
pts.SetPoint(13, 1, .5, 1)
pts.SetPoint(14, .5, 1, 1)
pts.SetPoint(15, 0, .5, 1)
pts.SetPoint(16, 0, 0, .5)
pts.SetPoint(17, 1, 0, .5)
pts.SetPoint(18, 1, 1, .5)
pts.SetPoint(19, 0, 1, .5)

c = vtkHexahedron()
c.Initialize(8, pts)
if not CheckCell(c, CheckHex):
    print("Failure for vtkHexahedron")
    sys.exit(1)

c = vtkQuadraticHexahedron()
c.Initialize(20, pts)
if not CheckCell(c, CheckHex):
    print("Failure for vtkQuadraticHexahedron")
    sys.exit(1)

# check pyramids
pts.SetPoint(0, 0, 0, 0)
pts.SetPoint(1, 1, 0, 0)
pts.SetPoint(2, 1, 1, 0)
pts.SetPoint(3, 0, 1, 0)
pts.SetPoint(4, 0, 0, 1)
pts.SetPoint(5, .5, 0, 0)
pts.SetPoint(6, 1, .5, 0)
pts.SetPoint(7, .5, 1, 0)
pts.SetPoint(8, 0, .5, 0)
pts.SetPoint(9, 0, 0, .5)
pts.SetPoint(10, .5, 0, .5)
pts.SetPoint(11, .5, .5, .5)
pts.SetPoint(12, 0, .5, .5)

c = vtkPyramid()
c.Initialize(5, pts)
if not CheckCell(c, CheckPyramid):
    print("Failure for vtkPyramid")
    sys.exit(1)

c = vtkQuadraticPyramid()
c.Initialize(13, pts)
if not CheckCell(c, CheckPyramid):
    print("Failure for vtkQuadraticPyramid")
    sys.exit(1)

# check wedges
pts.SetPoint(0, 0, 0, 0)
pts.SetPoint(1, 0, 1, 0)
pts.SetPoint(2, 1, 0, 0)
pts.SetPoint(3, 0, 0, 1)
pts.SetPoint(4, 0, 1, 1)
pts.SetPoint(5, 1, 0, 1)

pts.SetPoint(6, 0, .5, 0)
pts.SetPoint(7, .5, .5, 0)
pts.SetPoint(8, .5, 0, 0)
pts.SetPoint(9, 0, .5, 1)
pts.SetPoint(10, .5, .5, 1)
pts.SetPoint(11, .5, 0, 1)
pts.SetPoint(12, 0, 0, .5)
pts.SetPoint(13, 0, 1, .5)
pts.SetPoint(14, 1, 0, .5)

c = vtkWedge()
c.Initialize(6, pts)
if not CheckCell(c, CheckWedge):
    print("Failure for vtkWedge")
    sys.exit(1)

c = vtkQuadraticWedge()
c.Initialize(15, pts)
if not CheckCell(c, CheckWedge):
    print("Failure for vtkQuadraticWedge")
    sys.exit(1)


print("Success")
sys.exit(0)



#!/usr/bin/env python
from vtkmodules.vtkRenderingCore import (
    vtkRenderWindow,
    vtkRenderWindowInteractor,
    vtkRenderer,
)
from vtkmodules.vtkRenderingAnnotation import vtkLeaderActor2D
import vtkmodules.vtkInteractionStyle
import vtkmodules.vtkRenderingFreeType
import vtkmodules.vtkRenderingOpenGL2
from vtkmodules.util.misc import vtkGetDataRoot
VTK_DATA_ROOT = vtkGetDataRoot()

# create pipeline
#
leader = vtkLeaderActor2D()
leader.GetPositionCoordinate().SetCoordinateSystemToNormalizedViewport()
leader.GetPositionCoordinate().SetValue(0.1, 0.1)
leader.GetPosition2Coordinate().SetCoordinateSystemToNormalizedViewport()
leader.GetPosition2Coordinate().SetValue(0.75, 0.23)
leader.SetArrowStyleToFilled()
leader.SetLabel("")

leader2 = vtkLeaderActor2D()
leader2.GetPositionCoordinate().SetCoordinateSystemToNormalizedViewport()
leader2.GetPositionCoordinate().SetValue(0.9, 0.1)
leader2.GetPosition2Coordinate().SetCoordinateSystemToNormalizedViewport()
leader2.GetPosition2Coordinate().SetValue(0.75, 0.83)
leader2.SetArrowStyleToOpen()
leader2.SetArrowPlacementToPoint1()
leader2.SetLabel("Leader2")

leader3 = vtkLeaderActor2D()
leader3.GetPositionCoordinate().SetCoordinateSystemToNormalizedViewport()
leader3.GetPositionCoordinate().SetValue(0.1, 0.9)
leader3.GetPosition2Coordinate().SetCoordinateSystemToNormalizedViewport()
leader3.GetPosition2Coordinate().SetValue(0.6, 0.3)
leader3.SetArrowStyleToHollow()
leader3.SetLabel("Leader3")

leader4 = vtkLeaderActor2D()
leader4.GetPositionCoordinate().SetCoordinateSystemToNormalizedViewport()
leader4.GetPositionCoordinate().SetValue(0.1, 0.75)
leader4.GetPosition2Coordinate().SetCoordinateSystemToNormalizedViewport()
leader4.GetPosition2Coordinate().SetValue(0.1, 0.25)
leader4.SetArrowPlacementToNone()
leader4.SetRadius(1.0)
leader4.SetLabel("Leader4")
leader4.AutoLabelOn()

# Create graphics stuff
# Create the RenderWindow, Renderer and both Actors
#
ren1 = vtkRenderer()
renWin = vtkRenderWindow()
renWin.AddRenderer(ren1)
iren = vtkRenderWindowInteractor()
iren.SetRenderWindow(renWin)

ren1.AddActor(leader)
ren1.AddActor(leader2)
ren1.AddActor(leader3)
ren1.AddActor(leader4)

renWin.SetSize(250, 250)

# render the image
#
renWin.Render()
#iren.Start()



#!/usr/bin/env python
from vtkmodules.vtkCommonDataModel import (
    vtkImageData,
    vtkStaticPointLocator,
)

# This tests the static point locator on non-vtkPointSet
# datasets.
#

image = vtkImageData()
image.SetDimensions(50,50,50)

spl = vtkStaticPointLocator()
spl.SetDataSet(image)
spl.BuildLocator()



#!/usr/bin/env python
from vtkmodules.vtkFiltersCore import vtkFeatureEdges
from vtkmodules.vtkFiltersModeling import vtkImprintFilter
from vtkmodules.vtkFiltersSources import vtkSphereSource
from vtkmodules.vtkIOLegacy import vtkPolyDataWriter
from vtkmodules.vtkRenderingCore import (
    vtkActor,
    vtkPolyDataMapper,
    vtkRenderWindow,
    vtkRenderWindowInteractor,
    vtkRenderer,
)
import vtkmodules.vtkInteractionStyle
import vtkmodules.vtkRenderingFreeType
import vtkmodules.vtkRenderingOpenGL2

# Control the resolution of the test
radius = 10.0
res = 4
debug = 0
write = 0

# Create pipeline. Use two sphere sources:
# a portion of one sphere imprints on the other.
#
target = vtkSphereSource()
target.SetRadius(radius)
target.SetCenter(0,0,0)
target.LatLongTessellationOn()
target.SetThetaResolution(4*res)
target.SetPhiResolution(4*res)
target.SetStartTheta(0)
target.SetEndTheta(90)

imprint = vtkSphereSource()
imprint.SetRadius(radius)
imprint.SetCenter(0,0,0)
imprint.LatLongTessellationOn()
imprint.SetThetaResolution(8*res)
imprint.SetPhiResolution(4*res)
imprint.SetStartTheta(12)
imprint.SetEndTheta(57)
imprint.SetStartPhi(60.0)
imprint.SetEndPhi(120.0)

# Produce an imprint
imp = vtkImprintFilter()
imp.SetTargetConnection(target.GetOutputPort())
imp.SetImprintConnection(imprint.GetOutputPort())
imp.SetTolerance(0.1)
imp.SetMergeTolerance(0.055)
if debug:
    imp.SetDebugOutputTypeToTriangulationInput()
    imp.SetDebugCellId(10)
#imp.TriangulateOutputOn()
imp.Update()

if write:
  w = vtkPolyDataWriter()
  w.SetInputConnection(imp.GetOutputPort(1))
  w.SetFileName("imp.vtk")
  w.Write()

impMapper = vtkPolyDataMapper()
impMapper.SetInputConnection(imp.GetOutputPort())
impMapper.SetScalarRange(0,2)
impMapper.SetScalarModeToUseCellFieldData()
impMapper.SelectColorArray("ImprintedCells")

impActor = vtkActor()
impActor.SetMapper(impMapper)
impActor.GetProperty().SetColor(1,0,0)

imprintMapper = vtkPolyDataMapper()
imprintMapper.SetInputConnection(imprint.GetOutputPort())

imprintActor = vtkActor()
imprintActor.SetMapper(imprintMapper)
imprintActor.GetProperty().SetColor(1,1,1)

fedges = vtkFeatureEdges()
fedges.SetInputConnection(imp.GetOutputPort())
fedges.ExtractAllEdgeTypesOff()
fedges.NonManifoldEdgesOn()
fedges.BoundaryEdgesOn()

fedgesMapper = vtkPolyDataMapper()
fedgesMapper.SetInputConnection(fedges.GetOutputPort())

fedgesActor = vtkActor()
fedgesActor.SetMapper(fedgesMapper)
fedgesActor.GetProperty().SetRepresentationToWireframe()
fedgesActor.GetProperty().SetColor(0,1,0)

# Second output if needed
if debug:
    out2Mapper = vtkPolyDataMapper()
    out2Mapper.SetInputConnection(imp.GetOutputPort(1))
    out2Actor = vtkActor()
    out2Actor.SetMapper(out2Mapper)
    out2Actor.GetProperty().SetColor(1,1,0)

# Create the RenderWindow, Renderer
#
ren1 = vtkRenderer()
renWin = vtkRenderWindow()
renWin.AddRenderer( ren1 )
renWin.SetSize(300,200)

iren = vtkRenderWindowInteractor()
iren.SetRenderWindow(renWin)

ren1.AddActor(impActor)
#ren1.AddActor(imprintActor)
ren1.AddActor(fedgesActor)
if debug:
    ren1.AddActor(out2Actor)

cam = ren1.GetActiveCamera()
cam.SetPosition(1,0.5,0)
cam.SetFocalPoint(0,0,0)
ren1.ResetCamera()

renWin.Render()
iren.Start()



#!/usr/bin/env python
# -*- coding: utf-8 -*-



from vtkmodules.vtkCommonTransforms import vtkTransform

class SliceOrder(object):
    '''
        These transformations permute medical image data to maintain proper
        orientation regardless of the acquisition order.
        After applying these transforms with vtkTransformFilter,
        a view up of 0,-1,0 will result in the body part
        facing the viewer.
        NOTE: some transformations have a -1 scale factor
              for one of the components.
              To ensure proper polygon orientation and normal direction,
              you must apply the vtkPolyDataNormals filter.

        Naming:
        si - superior to inferior (top to bottom)
        iss - inferior to superior (bottom to top)
        ap - anterior to posterior (front to back)
        pa - posterior to anterior (back to front)
        lr - left to right
        rl - right to left

    '''

    si = vtkTransform()
    si.SetMatrix([1, 0, 0, 0, 0, 0, 1, 0, 0, -1, 0, 0, 0, 0, 0, 1])

    # 'is' is a reserved word in Python so use 'iss'
    iss = vtkTransform()
    iss.SetMatrix([1, 0, 0, 0, 0, 0, -1, 0, 0, -1, 0, 0, 0, 0, 0, 1])

    ap = vtkTransform()
    ap.Scale(1, -1, 1)

    pa = vtkTransform()
    pa.Scale(1, -1, -1)

    lr = vtkTransform()
    lr.SetMatrix([0, 0, -1, 0, 0, -1, 0, 0, 1, 0, 0, 0, 0, 0, 0, 1])

    rl = vtkTransform()
    rl.SetMatrix([0, 0, 1, 0, 0, -1, 0, 0, 1, 0, 0, 0, 0, 0, 0, 1])

    #
    # the previous transforms assume radiological views of the slices
    # (viewed from the feet).
    #  Othermodalities such as physical sectioning may view from the head.
    # These transforms modify the original with a 180 rotation about y
    #
    hf = vtkTransform()
    hf.SetMatrix([-1, 0, 0, 0, 0, 1, 0, 0, 0, 0, -1, 0, 0, 0, 0, 1])

    hfsi = vtkTransform()
    hfsi.Concatenate(hf.GetMatrix())
    hfsi.Concatenate(si.GetMatrix())

    hfis = vtkTransform()
    hfis.Concatenate(hf.GetMatrix())
    hfis.Concatenate(iss.GetMatrix())

    hfap = vtkTransform()
    hfap.Concatenate(hf.GetMatrix())
    hfap.Concatenate(ap.GetMatrix())

    hfpa = vtkTransform()
    hfpa.Concatenate(hf.GetMatrix())
    hfpa.Concatenate(pa.GetMatrix())

    hflr = vtkTransform()
    hflr.Concatenate(hf.GetMatrix())
    hflr.Concatenate(lr.GetMatrix())

    hfrl = vtkTransform()
    hfrl.Concatenate(hf.GetMatrix())
    hfrl.Concatenate(rl.GetMatrix())



#!/usr/bin/env python
import os
from vtkmodules.vtkFiltersCore import vtkContourFilter
from vtkmodules.vtkFiltersSources import vtkSphereSource
from vtkmodules.vtkIOLegacy import (
    vtkDataSetReader,
    vtkDataSetWriter,
)
from vtkmodules.vtkImagingHybrid import vtkVoxelModeller
from vtkmodules.vtkRenderingCore import (
    vtkActor,
    vtkPolyDataMapper,
    vtkRenderWindow,
    vtkRenderWindowInteractor,
    vtkRenderer,
)
import vtkmodules.vtkInteractionStyle
import vtkmodules.vtkRenderingFreeType
import vtkmodules.vtkRenderingOpenGL2
from vtkmodules.util.misc import vtkGetDataRoot
VTK_DATA_ROOT = vtkGetDataRoot()

# Now create the RenderWindow, Renderer and Interactor
#
ren1 = vtkRenderer()
renWin = vtkRenderWindow()
renWin.AddRenderer(ren1)
iren = vtkRenderWindowInteractor()
iren.SetRenderWindow(renWin)

sphereModel = vtkSphereSource()
sphereModel.SetThetaResolution(10)
sphereModel.SetPhiResolution(10)

voxelModel = vtkVoxelModeller()
voxelModel.SetInputConnection(sphereModel.GetOutputPort())
voxelModel.SetSampleDimensions(21, 21, 21)
voxelModel.SetModelBounds(-1.5, 1.5, -1.5, 1.5, -1.5, 1.5)
voxelModel.SetScalarTypeToBit()
voxelModel.SetForegroundValue(1)
voxelModel.SetBackgroundValue(0)

#
# If the current directory is writable, then test the writers
#
try:
    channel = open("voxelModel.vtk", "wb")
    channel.close()

    aWriter = vtkDataSetWriter()
    aWriter.SetFileName("voxelModel.vtk")
    aWriter.SetInputConnection(voxelModel.GetOutputPort())
    aWriter.Update()

    aReader = vtkDataSetReader()
    aReader.SetFileName("voxelModel.vtk")

    voxelSurface = vtkContourFilter()
    voxelSurface.SetInputConnection(aReader.GetOutputPort())
    voxelSurface.SetValue(0, .999)

    voxelMapper = vtkPolyDataMapper()
    voxelMapper.SetInputConnection(voxelSurface.GetOutputPort())

    voxelActor = vtkActor()
    voxelActor.SetMapper(voxelMapper)

    sphereMapper = vtkPolyDataMapper()
    sphereMapper.SetInputConnection(sphereModel.GetOutputPort())

    sphereActor = vtkActor()
    sphereActor.SetMapper(sphereMapper)

    ren1.AddActor(sphereActor)
    ren1.AddActor(voxelActor)
    ren1.SetBackground(.1, .2, .4)

    renWin.SetSize(256, 256)

    ren1.ResetCamera()
    ren1.GetActiveCamera().SetViewUp(0, -1, 0)
    ren1.GetActiveCamera().Azimuth(180)
    ren1.GetActiveCamera().Dolly(1.75)
    ren1.ResetCameraClippingRange()

    # cleanup
    #
    try:
        os.remove("voxelModel.vtk")
    except OSError:
        pass

    iren.Initialize()
    # render the image
#    iren.Start()

except IOError:
    print("Unable to test the writer/reader.")



#!/usr/bin/env python
from vtkmodules.vtkCommonTransforms import vtkTransform
from vtkmodules.vtkFiltersGeneral import vtkTransformPolyDataFilter
from vtkmodules.vtkFiltersModeling import vtkImprintFilter
from vtkmodules.vtkFiltersSources import vtkPlaneSource
from vtkmodules.vtkRenderingCore import (
    vtkActor,
    vtkPolyDataMapper,
    vtkRenderWindow,
    vtkRenderWindowInteractor,
    vtkRenderer,
)
import vtkmodules.vtkInteractionStyle
import vtkmodules.vtkRenderingFreeType
import vtkmodules.vtkRenderingOpenGL2

# Control the resolution of the test
res = 12

# Create pipeline. Use two plane sources:
# one plane imprints on the other plane.
#
plane1 = vtkPlaneSource()
plane1.SetXResolution(res)
plane1.SetYResolution(res)
plane1.SetOrigin(0,0,0)
plane1.SetPoint1(10,0,0)
plane1.SetPoint2(0,10,0)

plane2 = vtkPlaneSource()
plane2.SetXResolution(2*res)
plane2.SetYResolution(2*res)
plane2.SetOrigin(2.25,2.25,0)
plane2.SetPoint1(7.25,2.25,0)
plane2.SetPoint2(2.25,7.25,0)

xForm = vtkTransform()
xForm.RotateZ(-25)

xFormF = vtkTransformPolyDataFilter()
xFormF.SetInputConnection(plane2.GetOutputPort())
xFormF.SetTransform(xForm)

imp = vtkImprintFilter()
imp.SetTargetConnection(plane1.GetOutputPort())
imp.SetImprintConnection(xFormF.GetOutputPort())
imp.SetTolerance(0.001)
imp.Update()

mapper = vtkPolyDataMapper()
mapper.SetInputConnection(imp.GetOutputPort())

actor = vtkActor()
actor.SetMapper(mapper)
actor.GetProperty().SetRepresentationToWireframe()

# Create the RenderWindow, Renderer
#
ren1 = vtkRenderer()
renWin = vtkRenderWindow()
renWin.AddRenderer( ren1 )
renWin.SetSize(400,400)

iren = vtkRenderWindowInteractor()
iren.SetRenderWindow(renWin)

ren1.AddActor(actor)

renWin.Render()
iren.Start()



#!/usr/bin/env python
from vtkmodules.vtkFiltersCore import (
    vtkGlyph3D,
    vtkProbeFilter,
    vtkStructuredGridOutlineFilter,
)
from vtkmodules.vtkFiltersGeneral import vtkCursor3D
from vtkmodules.vtkFiltersSources import vtkConeSource
from vtkmodules.vtkIOParallel import vtkMultiBlockPLOT3DReader
from vtkmodules.vtkRenderingCore import (
    vtkActor,
    vtkPolyDataMapper,
    vtkRenderWindow,
    vtkRenderWindowInteractor,
    vtkRenderer,
)
import vtkmodules.vtkInteractionStyle
import vtkmodules.vtkRenderingFreeType
import vtkmodules.vtkRenderingOpenGL2
from vtkmodules.util.misc import vtkGetDataRoot
VTK_DATA_ROOT = vtkGetDataRoot()

ren1 = vtkRenderer()
renWin = vtkRenderWindow()
renWin.SetMultiSamples(0)
renWin.AddRenderer(ren1)
iren = vtkRenderWindowInteractor()
iren.SetRenderWindow(renWin)
# read data
reader = vtkMultiBlockPLOT3DReader()
reader.SetXYZFileName(VTK_DATA_ROOT + "/Data/combxyz.bin")
reader.SetQFileName(VTK_DATA_ROOT + "/Data/combq.bin")
reader.SetScalarFunctionNumber(110)
reader.Update()
output = reader.GetOutput().GetBlock(0)
# create outline
outlineF = vtkStructuredGridOutlineFilter()
outlineF.SetInputData(output)
outlineMapper = vtkPolyDataMapper()
outlineMapper.SetInputConnection(outlineF.GetOutputPort())
outline = vtkActor()
outline.SetMapper(outlineMapper)
outline.GetProperty().SetColor(0,0,0)
# create cursor
cursor = vtkCursor3D()
cursor.SetModelBounds(output.GetBounds())
cursor.SetFocalPoint(output.GetCenter())
cursor.AllOff()
cursor.AxesOn()
cursor.OutlineOn()
cursor.XShadowsOn()
cursor.YShadowsOn()
cursor.ZShadowsOn()
cursorMapper = vtkPolyDataMapper()
cursorMapper.SetInputConnection(cursor.GetOutputPort())
cursorActor = vtkActor()
cursorActor.SetMapper(cursorMapper)
cursorActor.GetProperty().SetColor(1,0,0)
# create probe
probe = vtkProbeFilter()
probe.SetInputData(cursor.GetFocus())
probe.SetSourceData(output)
# create a cone geometry for glyph
cone = vtkConeSource()
cone.SetResolution(16)
cone.SetRadius(0.25)
# create glyph
glyph = vtkGlyph3D()
glyph.SetInputConnection(probe.GetOutputPort())
glyph.SetSourceConnection(cone.GetOutputPort())
glyph.SetVectorModeToUseVector()
glyph.SetScaleModeToScaleByScalar()
glyph.SetScaleFactor(.0002)
glyphMapper = vtkPolyDataMapper()
glyphMapper.SetInputConnection(glyph.GetOutputPort())
glyphActor = vtkActor()
glyphActor.SetMapper(glyphMapper)
ren1.AddActor(outline)
ren1.AddActor(cursorActor)
ren1.AddActor(glyphActor)
ren1.SetBackground(1.0,1.0,1.0)
renWin.SetSize(200,200)
ren1.ResetCamera()
ren1.GetActiveCamera().Elevation(60)
ren1.ResetCameraClippingRange()
renWin.Render()
iren.Initialize()
# prevent the tk window from showing up then start the event loop
# --- end of script --



#!/usr/bin/env python
import sys
from vtkmodules.vtkCommonCore import (
    vtkFloatArray,
    vtkIdTypeArray,
    vtkPoints,
)
from vtkmodules.vtkCommonDataModel import (
    VTK_QUADRATIC_QUAD,
    vtkUnstructuredGrid,
)
from vtkmodules.vtkFiltersGeometry import vtkDataSetSurfaceFilter
from vtkmodules.test import Testing

# This script creates an unstructured grid of 4 quadratic quads
# with vtkIdTypeArray and vtkFloatArray point data and vtkIdTypeArray cell data.
#
# When vtkDataSetSurfaceFilter has sub-division level < 2 there is no
# interpolation being done so the point-data idtype array is expected to be copied

class TestDataSetSurfaceFilter(Testing.vtkTest):
    def setUp(self):
        # corner-points (9)
        c0=[[0,0,0],[1,0,0],[2,0,0]]
        c1=[[0,1,0],[1,1,0],[2,1,0]]
        c2=[[0,2,0],[1,2,0],[2,2,0]]
        # mid nodes on horizontal edges (6)
        mx0=[[.5,0,0],[1.5,0,0]]
        mx1=[[.5,1,0],[1.5,1,0]]
        mx2=[[.5,2,0],[1.5,2,0]]
        # mid nodes on vertical edges (6)
        my0=[[0,.5,0],[1,.5,0],[2,.5,0]]
        my1=[[0,1.5,0],[1,1.5,0],[2,1.5,0]]
        #
        # create points and point data
        pts=vtkPoints()
        pts.Allocate(21)
        self.point_ids=vtkIdTypeArray()
        self.point_ids.SetName('point-ids')
        self.point_values=vtkFloatArray()
        self.point_values.SetName('point-values')
        i=1
        for coords in (c0,c1,c2,mx0,mx1,mx2,my0,my1):
            for xyz in coords:
                pts.InsertNextPoint(xyz[0],xyz[1],xyz[2])
                self.point_ids.InsertNextValue(i+100)
                i+=1
                self.point_values.InsertNextValue( float(i) / 10 )
        #
        # create cells and cell data
        corners=[(0,1,4,3),
                 (1,2,5,4),
                 (3,4,7,6),
                 (4,5,8,7)]
        midnodes=[(9+0,15+1,9+2,15+0),
                  (9+1,15+2,9+3,15+1),
                  (9+2,15+4,9+4,15+3),
                  (9+3,15+5,9+5,15+4)]
        self.ug=vtkUnstructuredGrid()
        self.ug.SetPoints(pts)
        self.ug.Allocate(4)
        self.cell_ids=vtkIdTypeArray()
        self.cell_ids.SetName('cell-ids')
        i=1
        for (c,m) in zip(corners,midnodes):
            self.ug.InsertNextCell(VTK_QUADRATIC_QUAD,8,(c+m))
            self.cell_ids.InsertNextValue(i+1000)
            i+=1
        self.ug.GetPointData().AddArray(self.point_ids)
        self.ug.GetPointData().AddArray(self.point_values)
        self.ug.GetCellData().AddArray(self.cell_ids)
        #
        # create the surface-filter
        surface=vtkDataSetSurfaceFilter()
        surface.SetInputData(self.ug)
        surface.Update()

        self.output=surface.GetOutput()

    def testNumberOfPoints(self):
        self.assertEqual(self.output.GetNumberOfPoints(),
                         self.ug.GetNumberOfPoints())

    def testPointIds(self):
        out_point_ids=self.output.GetPointData().GetArray('point-ids')
        self.assertTrue(out_point_ids)
        self.assertEqual(out_point_ids.GetNumberOfTuples(),
                         self.point_ids.GetNumberOfTuples())
        self.assertEqual(out_point_ids.GetRange(),
                         self.point_ids.GetRange())

    def testPointValues(self):
        out_point_values=self.output.GetPointData().GetArray('point-values')
        self.assertTrue(out_point_values)
        self.assertEqual(out_point_values.GetNumberOfTuples(),
                         self.point_values.GetNumberOfTuples())
        self.assertEqual(out_point_values.GetRange(),
                         self.point_values.GetRange())

    def testCellIds(self):
        out_cell_ids=self.output.GetCellData().GetArray('cell-ids')
        self.assertTrue(out_cell_ids)
        self.assertGreater(out_cell_ids.GetNumberOfTuples(),
                           self.cell_ids.GetNumberOfTuples())
        self.assertEqual(out_cell_ids.GetRange(),
                         self.cell_ids.GetRange())

if __name__ == "__main__":
    Testing.main([(TestDataSetSurfaceFilter,'test')])



#!/usr/bin/env python

# Demonstrate computation of volumes and areas of objects
# defined by polygonal meshes
from vtkmodules.vtkCommonCore import vtkPoints
from vtkmodules.vtkCommonDataModel import (
    vtkCellArray,
    vtkPolyData,
)
from vtkmodules.vtkFiltersCore import vtkMultiObjectMassProperties
from vtkmodules.vtkRenderingCore import (
    vtkActor,
    vtkPolyDataMapper,
    vtkRenderWindow,
    vtkRenderWindowInteractor,
    vtkRenderer,
)
import vtkmodules.vtkInteractionStyle
import vtkmodules.vtkRenderingFreeType
import vtkmodules.vtkRenderingOpenGL2
from vtkmodules.util.misc import vtkGetDataRoot

VTK_DATA_ROOT = vtkGetDataRoot()

# Create the RenderWindow, Renderer
#
ren = vtkRenderer()
renWin = vtkRenderWindow()
renWin.AddRenderer(ren)

iren = vtkRenderWindowInteractor()
iren.SetRenderWindow(renWin)

# Create "blocks" out of combinations of polygons, with
# different orientations, each with total volume of 1
# and total area of 6. Additionally, a non-manifold
# polygonal "mess" tests the invalid state.
polyData = vtkPolyData()
pts = vtkPoints()
polys = vtkCellArray()
polyData.SetPoints(pts)
polyData.SetPolys(polys)

pts.SetNumberOfPoints(42)
# First block
pts.SetPoint(0, -2, -2, -0.5)
pts.SetPoint(1, -1, -2, -0.5)
pts.SetPoint(2, -2, -1, -0.5)
pts.SetPoint(3, -1, -1, -0.5)
pts.SetPoint(4, -2, -2, 0.5)
pts.SetPoint(5, -1, -2, 0.5)
pts.SetPoint(6, -2, -1, 0.5)
pts.SetPoint(7, -1, -1, 0.5)

# Second block
pts.SetPoint(8, 1, -2, -0.5)
pts.SetPoint(9, 2, -2, -0.5)
pts.SetPoint(10, 1, -1, -0.5)
pts.SetPoint(11, 2, -1, -0.5)
pts.SetPoint(12, 1, -2, 0.5)
pts.SetPoint(13, 2, -2, 0.5)
pts.SetPoint(14, 1, -1, 0.5)
pts.SetPoint(15, 2, -1, 0.5)

# Third block
pts.SetPoint(16, -2, 1, -0.5)
pts.SetPoint(17, -1, 1, -0.5)
pts.SetPoint(18, -2, 2, -0.5)
pts.SetPoint(19, -1, 2, -0.5)
pts.SetPoint(20, -2, 1, 0.5)
pts.SetPoint(21, -1, 1, 0.5)
pts.SetPoint(22, -2, 2, 0.5)
pts.SetPoint(23, -1, 2, 0.5)

# Fourth block
pts.SetPoint(24, 1, 1, -0.5)
pts.SetPoint(25, 2, 1, -0.5)
pts.SetPoint(26, 1, 2, -0.5)
pts.SetPoint(27, 2, 2, -0.5)
pts.SetPoint(28, 1, 1, 0.5)
pts.SetPoint(29, 2, 1, 0.5)
pts.SetPoint(30, 1, 2, 0.5)
pts.SetPoint(31, 2, 2, 0.5)

# Invalid poly mess (a "X")
pts.SetPoint(32, 0, -0.5, -0.5)
pts.SetPoint(33, 0, 0.5, -0.5)
pts.SetPoint(34, -0.5, -0.5, 0)
pts.SetPoint(35, 0, -0.5, 0)
pts.SetPoint(36, 0.5, -0.5, 0)
pts.SetPoint(37, -0.5, 0.5, 0)
pts.SetPoint(38, 0, 0.5, 0)
pts.SetPoint(39, 0.5, 0.5, 0)
pts.SetPoint(40, 0, -0.5, 0.5)
pts.SetPoint(41, 0, 0.5, 0.5)

# First block - all quads, consistent order
polys.InsertNextCell(4)
polys.InsertCellPoint(0)
polys.InsertCellPoint(1)
polys.InsertCellPoint(3)
polys.InsertCellPoint(2)

polys.InsertNextCell(4)
polys.InsertCellPoint(4)
polys.InsertCellPoint(6)
polys.InsertCellPoint(7)
polys.InsertCellPoint(5)

polys.InsertNextCell(4)
polys.InsertCellPoint(0)
polys.InsertCellPoint(4)
polys.InsertCellPoint(5)
polys.InsertCellPoint(1)

polys.InsertNextCell(4)
polys.InsertCellPoint(3)
polys.InsertCellPoint(7)
polys.InsertCellPoint(6)
polys.InsertCellPoint(2)

polys.InsertNextCell(4)
polys.InsertCellPoint(1)
polys.InsertCellPoint(5)
polys.InsertCellPoint(7)
polys.InsertCellPoint(3)

polys.InsertNextCell(4)
polys.InsertCellPoint(2)
polys.InsertCellPoint(6)
polys.InsertCellPoint(4)
polys.InsertCellPoint(0)

# Second block - quads with a reversed polygon
polys.InsertNextCell(4)
polys.InsertCellPoint(8)
polys.InsertCellPoint(9)
polys.InsertCellPoint(11)
polys.InsertCellPoint(10)

polys.InsertNextCell(4)
polys.InsertCellPoint(12)
polys.InsertCellPoint(13)
polys.InsertCellPoint(15)
polys.InsertCellPoint(14)

polys.InsertNextCell(4)
polys.InsertCellPoint(8)
polys.InsertCellPoint(12)
polys.InsertCellPoint(13)
polys.InsertCellPoint(9)

polys.InsertNextCell(4)
polys.InsertCellPoint(11)
polys.InsertCellPoint(15)
polys.InsertCellPoint(14)
polys.InsertCellPoint(10)

polys.InsertNextCell(4)
polys.InsertCellPoint(9)
polys.InsertCellPoint(13)
polys.InsertCellPoint(15)
polys.InsertCellPoint(11)

polys.InsertNextCell(4)
polys.InsertCellPoint(10)
polys.InsertCellPoint(14)
polys.InsertCellPoint(12)
polys.InsertCellPoint(8)

# Third block - with triangles + quads
polys.InsertNextCell(3)
polys.InsertCellPoint(16)
polys.InsertCellPoint(17)
polys.InsertCellPoint(19)

polys.InsertNextCell(3)
polys.InsertCellPoint(19)
polys.InsertCellPoint(18)
polys.InsertCellPoint(16)

polys.InsertNextCell(4)
polys.InsertCellPoint(20)
polys.InsertCellPoint(22)
polys.InsertCellPoint(23)
polys.InsertCellPoint(21)

polys.InsertNextCell(4)
polys.InsertCellPoint(16)
polys.InsertCellPoint(20)
polys.InsertCellPoint(21)
polys.InsertCellPoint(17)

polys.InsertNextCell(4)
polys.InsertCellPoint(19)
polys.InsertCellPoint(23)
polys.InsertCellPoint(22)
polys.InsertCellPoint(18)

polys.InsertNextCell(4)
polys.InsertCellPoint(17)
polys.InsertCellPoint(21)
polys.InsertCellPoint(23)
polys.InsertCellPoint(19)

polys.InsertNextCell(4)
polys.InsertCellPoint(18)
polys.InsertCellPoint(22)
polys.InsertCellPoint(20)
polys.InsertCellPoint(16)

# Fourth block - with triangles + quads + reversals
polys.InsertNextCell(3)
polys.InsertCellPoint(24)
polys.InsertCellPoint(25)
polys.InsertCellPoint(27)

polys.InsertNextCell(3)
polys.InsertCellPoint(26)
polys.InsertCellPoint(27)
polys.InsertCellPoint(24)

polys.InsertNextCell(4)
polys.InsertCellPoint(28)
polys.InsertCellPoint(30)
polys.InsertCellPoint(31)
polys.InsertCellPoint(29)

polys.InsertNextCell(4)
polys.InsertCellPoint(24)
polys.InsertCellPoint(28)
polys.InsertCellPoint(29)
polys.InsertCellPoint(25)

polys.InsertNextCell(4)
polys.InsertCellPoint(27)
polys.InsertCellPoint(31)
polys.InsertCellPoint(30)
polys.InsertCellPoint(26)

polys.InsertNextCell(4)
polys.InsertCellPoint(25)
polys.InsertCellPoint(29)
polys.InsertCellPoint(31)
polys.InsertCellPoint(27)

polys.InsertNextCell(4)
polys.InsertCellPoint(26)
polys.InsertCellPoint(30)
polys.InsertCellPoint(28)
polys.InsertCellPoint(24)

# Non-manifold Poly mess - four quads forming a "X"
polys.InsertNextCell(4)
polys.InsertCellPoint(32)
polys.InsertCellPoint(33)
polys.InsertCellPoint(38)
polys.InsertCellPoint(35)

polys.InsertNextCell(4)
polys.InsertCellPoint(34)
polys.InsertCellPoint(35)
polys.InsertCellPoint(38)
polys.InsertCellPoint(37)

polys.InsertNextCell(4)
polys.InsertCellPoint(35)
polys.InsertCellPoint(36)
polys.InsertCellPoint(39)
polys.InsertCellPoint(38)

polys.InsertNextCell(4)
polys.InsertCellPoint(35)
polys.InsertCellPoint(38)
polys.InsertCellPoint(41)
polys.InsertCellPoint(40)

# Compute volumes
massP = vtkMultiObjectMassProperties()
massP.SetInputData(polyData)
massP.Update()

print("Mass Properties: {0}".format(massP))
print("Number Objects: {0}".format(massP.GetNumberOfObjects()))
print("All Valid: {0}".format(massP.GetAllValid()))
print("Total Area: {0}".format(massP.GetTotalArea()))
print("Total Volume: {0}".format(massP.GetTotalVolume()))

numObjects = massP.GetNumberOfObjects()
validArray = massP.GetOutput().GetFieldData().GetArray("ObjectValidity")
areaArray = massP.GetOutput().GetFieldData().GetArray("ObjectAreas")
volArray = massP.GetOutput().GetFieldData().GetArray("ObjectVolumes")
centroidArray = massP.GetOutput().GetFieldData().GetArray("ObjectCentroids")
print("Object ID, Valid, Area, Volume, Centroid")
for i in range(0, numObjects):
    valid = validArray.GetTuple1(i)
    area = areaArray.GetTuple1(i)
    vol = volArray.GetTuple1(i)
    centroid = centroidArray.GetTuple3(i)
    print(i, valid, area, vol, centroid)

mapper = vtkPolyDataMapper()
mapper.SetInputConnection(massP.GetOutputPort())
mapper.ScalarVisibilityOff()

actor = vtkActor()
actor.SetMapper(mapper)

# Render it
ren.AddActor(actor)

ren.GetActiveCamera().SetPosition(0.5, 0.5, 1)
ren.GetActiveCamera().SetFocalPoint(0, 0, 0)
ren.ResetCamera()

renWin.Render()
iren.Start()



#!/usr/bin/env python
from vtkmodules.vtkCommonExecutionModel import vtkCompositeDataPipeline
from vtkmodules.vtkFiltersGeometry import vtkGeometryFilter
from vtkmodules.vtkIOEnSight import vtkEnSightMasterServerReader
from vtkmodules.vtkRenderingCore import (
    vtkActor,
    vtkHierarchicalPolyDataMapper,
    vtkRenderWindow,
    vtkRenderWindowInteractor,
    vtkRenderer,
)
import vtkmodules.vtkInteractionStyle
import vtkmodules.vtkRenderingFreeType
import vtkmodules.vtkRenderingOpenGL2
from vtkmodules.util.misc import vtkGetDataRoot
VTK_DATA_ROOT = vtkGetDataRoot()

# create a rendering window and renderer
ren1 = vtkRenderer()
renWin = vtkRenderWindow()
renWin.AddRenderer(ren1)
renWin.StereoCapableWindowOn()
iren = vtkRenderWindowInteractor()
iren.SetRenderWindow(renWin)
reader = vtkEnSightMasterServerReader()
# Make sure all algorithms use the composite data pipeline
cdp = vtkCompositeDataPipeline()
reader.SetDefaultExecutivePrototype(cdp)
reader.SetCaseFileName(VTK_DATA_ROOT + "/Data/EnSight/elements.sos")
reader.SetCurrentPiece(0)
geom0 = vtkGeometryFilter()
geom0.SetInputConnection(reader.GetOutputPort())
mapper0 = vtkHierarchicalPolyDataMapper()
mapper0.SetInputConnection(geom0.GetOutputPort())
mapper0.SetColorModeToMapScalars()
mapper0.SetScalarModeToUsePointFieldData()
mapper0.ColorByArrayComponent("pointScalars",0)
mapper0.SetScalarRange(0,112)
actor0 = vtkActor()
actor0.SetMapper(mapper0)
# assign our actor to the renderer
ren1.AddActor(actor0)
# enable user interface interactor
iren.Initialize()
# prevent the tk window from showing up then start the event loop
reader.SetDefaultExecutivePrototype(None)
# --- end of script --



#!/usr/bin/env python
from vtkmodules.vtkIOImage import vtkImageReader2Factory
from vtkmodules.vtkImagingCore import vtkImageExtractComponents
from vtkmodules.vtkImagingFourier import (
    vtkImageFFT,
    vtkImageIdealHighPass,
    vtkImageRFFT,
)
from vtkmodules.vtkInteractionImage import vtkImageViewer
import vtkmodules.vtkInteractionStyle
import vtkmodules.vtkRenderingFreeType
import vtkmodules.vtkRenderingOpenGL2
from vtkmodules.util.misc import vtkGetDataRoot
VTK_DATA_ROOT = vtkGetDataRoot()

# This script shows the result of an ideal highpass filter in spatial domain
# Image pipeline
createReader = vtkImageReader2Factory()
reader = createReader.CreateImageReader2(VTK_DATA_ROOT + "/Data/fullhead15.png")
reader.SetFileName(VTK_DATA_ROOT + "/Data/fullhead15.png")
fft = vtkImageFFT()
fft.SetInputConnection(reader.GetOutputPort())
highPass = vtkImageIdealHighPass()
highPass.SetInputConnection(fft.GetOutputPort())
highPass.SetXCutOff(0.1)
highPass.SetYCutOff(0.1)
highPass.ReleaseDataFlagOff()
rfft = vtkImageRFFT()
rfft.SetInputConnection(highPass.GetOutputPort())
real = vtkImageExtractComponents()
real.SetInputConnection(rfft.GetOutputPort())
real.SetComponents(0)
viewer = vtkImageViewer()
viewer.SetInputConnection(real.GetOutputPort())
viewer.SetColorWindow(500)
viewer.SetColorLevel(0)
viewer.Render()
reader.UnRegister(viewer) # not needed in python
# --- end of script --



#!/usr/bin/env python
from vtkmodules.vtkImagingGeneral import vtkImageConvolve
from vtkmodules.vtkImagingSources import vtkImageCanvasSource2D
from vtkmodules.vtkInteractionImage import vtkImageViewer
import vtkmodules.vtkInteractionStyle
import vtkmodules.vtkRenderingFreeType
import vtkmodules.vtkRenderingOpenGL2
from vtkmodules.util.misc import vtkGetDataRoot
VTK_DATA_ROOT = vtkGetDataRoot()

# Show the constant kernel.  Smooth an impulse function.
s1 = vtkImageCanvasSource2D()
s1.SetScalarTypeToFloat()
s1.SetExtent(0,255,0,255,0,0)
s1.SetDrawColor(0)
s1.FillBox(0,255,0,255)
s1.SetDrawColor(1.0)
s1.FillBox(75,175,75,175)
convolve = vtkImageConvolve()
convolve.SetInputConnection(s1.GetOutputPort())
convolve.SetKernel5x5([1,1,1,1,1,5,4,3,2,1,5,4,3,2,1,5,4,3,2,1,1,1,1,1,1])
viewer = vtkImageViewer()
viewer.SetInputConnection(convolve.GetOutputPort())
viewer.SetColorWindow(18)
viewer.SetColorLevel(9)
viewer.Render()
# --- end of script --



#!/usr/bin/env python

import array
import vtkmodules.vtkCommonCore
from vtkmodules.vtkCommonCore import vtkSOADataArrayTemplate

# types can be specified either with one of the strings listed below,
# or with a numpy dtype.  You can get a list of types by calling the
# method vtkSOADataArrayTemplate.keys().
types = ['char', 'int8', 'uint8', 'int16', 'uint16', 'int32', 'uint32',
         'int64', 'uint64', 'float32', 'float64']
formats = ['c', 'b', 'B', 'h', 'H', 'i', 'I', 'q', 'Q', 'f', 'd']

numarraytypes = 1
try:
    vtkScaledSOADataArrayTemplate = vtkmodules.vtkCommonCore.vtkScaledSOADataArrayTemplate
    numarraytypes = 2
except AttributeError:
    pass

for i in range(numarraytypes):
    for T in types:
        # instantiate the class for type T
        if i == 0:
            a = vtkSOADataArrayTemplate[T]()
        else:
            a = vtkScaledSOADataArrayTemplate[T]()
        a.SetNumberOfComponents(3)
        # do a simple set/get test
        a.SetNumberOfTuples(2)
        a.SetTuple(0, (1,2,3))
        assert a.GetTuple(0) == (1,2,3)
        # test the typed interface
        if T != 'char':
            a.SetTypedTuple(0, (3,4,6))
            t = [0,0,0]
            a.GetTypedTuple(0, t)
            assert t == [3,4,6]
            assert a.GetTypedComponent(0, 0) == 3
            assert a.GetTypedComponent(0, 1) == 4
            assert a.GetTypedComponent(0, 2) == 6
        # test SetArray for types compatible with 'array' module
        if T not in ('char', 'int64', 'uint64'):
            t = formats[types.index(T)]
            b1 = array.array(t, [10, 11, 12, 20])
            b2 = array.array(t, [14, 15, 16, 30])
            b3 = array.array(t, [17, 18, 19, 40])
            a.SetArray(0, b1, 4, True, True)
            a.SetArray(1, b2, 4, True, True)
            a.SetArray(2, b3, 4, True, True)
            assert a.GetNumberOfTuples() == 4
            assert a.GetTuple(0) == (10, 14, 17)
            assert a.GetTuple(1) == (11, 15, 18)
            assert a.GetTuple(2) == (12, 16, 19)
            assert a.GetTuple(3) == (20, 30, 40)

exit()



#!/usr/bin/env python

"""
vtkEnSightWriter test for writing node/element variables

This test demonstrates that vtkEnSightWriter supports writing
"scalar", "vector", "tensor symm" and "tensor asym" variables for
"per node" and "per cell" locations, and vtkEnSightGoldBinaryReader
is able to read them back.

Values of the created variables have a regular structure, eg. "PointVectors"
has values (1001, 1002, 1003), (2001, 2002, 2003)... for easier debugging.

"""

import vtk
from vtk.util.misc import vtkGetTempDir
import os.path
VTK_TEMP_DIR = vtkGetTempDir()

# Create some geometry
cell_type_source = vtk.vtkCellTypeSource()
cell_type_source.SetCellType(vtk.VTK_HEXAHEDRON)
cell_type_source.SetBlocksDimensions(2, 2, 2)
cell_type_source.Update()
reference_mesh = cell_type_source.GetOutput()
num_points = reference_mesh.GetNumberOfPoints()
num_cells = reference_mesh.GetNumberOfCells()

# Create testing variables
def fill_array(arr):
    for i in range(arr.GetNumberOfTuples()):
        arr.SetTuple(i, [1000*(i+1) + (j+1) for j in range(arr.GetNumberOfComponents())])

for dimension, name in [(1, "PointScalars"), (3, "PointVectors"), (6, "PointTensors6"), (9, "PointTensors9")]:
    arr = vtk.vtkFloatArray()
    arr.SetName(name)
    arr.SetNumberOfComponents(dimension)
    arr.SetNumberOfTuples(num_points)
    fill_array(arr)
    reference_mesh.GetPointData().AddArray(arr)

for dimension, name in [(1, "CellScalars"), (3, "CellVectors"), (6, "CellTensors6"), (9, "CellTensors9")]:
    arr = vtk.vtkFloatArray()
    arr.SetName(name)
    arr.SetNumberOfComponents(dimension)
    arr.SetNumberOfTuples(num_cells)
    fill_array(arr)
    reference_mesh.GetCellData().AddArray(arr)

# Create auxiliary variables to make sure we're mapping points/cells correctly to reference data.
# Note that we unfortunately cannot use vtkEnSightWriter WriteNodeIDs/WriteElementIDs since
# vtkEnSightGoldBinaryReader doesn't provide access to these arrays.
point_ids = vtk.vtkFloatArray()
point_ids.SetName("VTKPointIDs")
point_ids.SetNumberOfComponents(1)
point_ids.SetNumberOfTuples(num_points)
for i in range(num_points):
    point_ids.SetValue(i, i)
reference_mesh.GetPointData().AddArray(point_ids)

cell_ids = vtk.vtkFloatArray()
cell_ids.SetName("VTKCellIDs")
cell_ids.SetNumberOfComponents(1)
cell_ids.SetNumberOfTuples(num_points)
for i in range(num_cells):
    cell_ids.SetValue(i, i)
reference_mesh.GetCellData().AddArray(cell_ids)

# Write the case and read it back
writer = vtk.vtkEnSightWriter()
writer.SetFileName(os.path.join(VTK_TEMP_DIR, "ensightWriterVariables.case"))
writer.SetInputData(reference_mesh)
writer.Write()
writer.WriteCaseFile(0)

reader = vtk.vtkEnSightGoldBinaryReader()
reader.SetCaseFileName(os.path.join(VTK_TEMP_DIR, "ensightWriterVariables.0.case"))
reader.ReadAllVariablesOn()
reader.Update()
mesh = reader.GetOutput().GetBlock(0)

# vtkEnSightWriter appends "_n" or "_c" suffix to the names
point_array_names = [
    ("PointScalars", "PointScalars_n"),
    ("PointVectors", "PointVectors_n"),
    ("PointTensors6", "PointTensors6_n"),
    ("PointTensors9", "PointTensors9_n"),
]

cell_array_names = [
    ("CellScalars", "CellScalars_c"),
    ("CellVectors", "CellVectors_c"),
    ("CellTensors6", "CellTensors6_c"),
    ("CellTensors9", "CellTensors9_c"),
]

point_id_to_reference = {i: int(mesh.GetPointData().GetArray("VTKPointIDs_n").GetValue(i)) for i in range(num_points)}
cell_id_to_reference = {i: int(mesh.GetCellData().GetArray("VTKCellIDs_c").GetValue(i)) for i in range(num_cells)}

# Check point variables
for reference_name, name in point_array_names:
    reference_arr = reference_mesh.GetPointData().GetArray(reference_name)
    arr = mesh.GetPointData().GetArray(name)
    assert reference_arr is not None
    assert arr is not None

    for i in range(num_points):
        j = point_id_to_reference[i]
        reference_val = reference_arr.GetTuple(i)
        val = arr.GetTuple(j)
        assert reference_val == val

# Check cell variables
for reference_name, name in cell_array_names:
    reference_arr = reference_mesh.GetCellData().GetArray(reference_name)
    arr = mesh.GetCellData().GetArray(name)
    assert reference_arr is not None
    assert arr is not None

    for i in range(num_cells):
        j = cell_id_to_reference[i]
        reference_val = reference_arr.GetTuple(i)
        val = arr.GetTuple(j)
        assert reference_val == val



#!/usr/bin/env python
from vtkmodules.vtkCommonCore import (
    vtkPoints,
    vtkUnsignedCharArray,
)
from vtkmodules.vtkCommonDataModel import (
    vtkCellArray,
    vtkPolyData,
)
from vtkmodules.vtkCommonTransforms import vtkTransform
from vtkmodules.vtkFiltersGeneral import vtkTransformPolyDataFilter
from vtkmodules.vtkRenderingCore import (
    vtkActor,
    vtkCamera,
    vtkPolyDataMapper,
    vtkRenderWindow,
    vtkRenderWindowInteractor,
    vtkRenderer,
    vtkTransformInterpolator,
)
import vtkmodules.vtkInteractionStyle
import vtkmodules.vtkRenderingFreeType
import vtkmodules.vtkRenderingOpenGL2
from vtkmodules.util.misc import vtkGetDataRoot
VTK_DATA_ROOT = vtkGetDataRoot()

# create two boxes and interpolate between them
#
pts = vtkPoints()
pts.InsertNextPoint(-1,-1,-1)
pts.InsertNextPoint(1,-1,-1)
pts.InsertNextPoint(1,1,-1)
pts.InsertNextPoint(-1,1,-1)
pts.InsertNextPoint(-1,-1,1)
pts.InsertNextPoint(1,-1,1)
pts.InsertNextPoint(1,1,1)
pts.InsertNextPoint(-1,1,1)
faces = vtkCellArray()
faces.InsertNextCell(4)
faces.InsertCellPoint(0)
faces.InsertCellPoint(3)
faces.InsertCellPoint(2)
faces.InsertCellPoint(1)
faces.InsertNextCell(4)
faces.InsertCellPoint(4)
faces.InsertCellPoint(5)
faces.InsertCellPoint(6)
faces.InsertCellPoint(7)
faces.InsertNextCell(4)
faces.InsertCellPoint(0)
faces.InsertCellPoint(1)
faces.InsertCellPoint(5)
faces.InsertCellPoint(4)
faces.InsertNextCell(4)
faces.InsertCellPoint(1)
faces.InsertCellPoint(2)
faces.InsertCellPoint(6)
faces.InsertCellPoint(5)
faces.InsertNextCell(4)
faces.InsertCellPoint(2)
faces.InsertCellPoint(3)
faces.InsertCellPoint(7)
faces.InsertCellPoint(6)
faces.InsertNextCell(4)
faces.InsertCellPoint(3)
faces.InsertCellPoint(0)
faces.InsertCellPoint(4)
faces.InsertCellPoint(7)
faceColors = vtkUnsignedCharArray()
faceColors.SetNumberOfComponents(3)
faceColors.SetNumberOfTuples(3)
faceColors.InsertComponent(0,0,255)
faceColors.InsertComponent(0,1,0)
faceColors.InsertComponent(0,2,0)
faceColors.InsertComponent(1,0,0)
faceColors.InsertComponent(1,1,255)
faceColors.InsertComponent(1,2,0)
faceColors.InsertComponent(2,0,255)
faceColors.InsertComponent(2,1,255)
faceColors.InsertComponent(2,2,0)
faceColors.InsertComponent(3,0,0)
faceColors.InsertComponent(3,1,0)
faceColors.InsertComponent(3,2,255)
faceColors.InsertComponent(4,0,255)
faceColors.InsertComponent(4,1,0)
faceColors.InsertComponent(4,2,255)
faceColors.InsertComponent(5,0,0)
faceColors.InsertComponent(5,1,255)
faceColors.InsertComponent(5,2,255)
cube = vtkPolyData()
cube.SetPoints(pts)
cube.SetPolys(faces)
cube.GetCellData().SetScalars(faceColors)
t1 = vtkTransform()
t1.Translate(1,2,3)
t1.RotateX(15)
t1.Scale(4,2,1)
tpdf1 = vtkTransformPolyDataFilter()
tpdf1.SetInputData(cube)
tpdf1.SetTransform(t1)
cube1Mapper = vtkPolyDataMapper()
cube1Mapper.SetInputConnection(tpdf1.GetOutputPort())
cube1 = vtkActor()
cube1.SetMapper(cube1Mapper)
t2 = vtkTransform()
t2.Translate(5,10,15)
t2.RotateX(22.5)
t2.RotateY(15)
t2.RotateZ(85)
t2.Scale(1,2,4)
tpdf2 = vtkTransformPolyDataFilter()
tpdf2.SetInputData(cube)
tpdf2.SetTransform(t2)
cube2Mapper = vtkPolyDataMapper()
cube2Mapper.SetInputConnection(tpdf2.GetOutputPort())
cube2 = vtkActor()
cube2.SetMapper(cube2Mapper)
t3 = vtkTransform()
t3.Translate(5,-10,15)
t3.RotateX(13)
t3.RotateY(72)
t3.RotateZ(-15)
t3.Scale(2,4,1)
tpdf3 = vtkTransformPolyDataFilter()
tpdf3.SetInputData(cube)
tpdf3.SetTransform(t3)
cube3Mapper = vtkPolyDataMapper()
cube3Mapper.SetInputConnection(tpdf3.GetOutputPort())
cube3 = vtkActor()
cube3.SetMapper(cube3Mapper)
t4 = vtkTransform()
t4.Translate(10,-5,5)
t4.RotateX(66)
t4.RotateY(19)
t4.RotateZ(24)
t4.Scale(2,.5,1)
tpdf4 = vtkTransformPolyDataFilter()
tpdf4.SetInputData(cube)
tpdf4.SetTransform(t4)
cube4Mapper = vtkPolyDataMapper()
cube4Mapper.SetInputConnection(tpdf4.GetOutputPort())
cube4 = vtkActor()
cube4.SetMapper(cube4Mapper)
# Interpolate the transformation
cubeMapper = vtkPolyDataMapper()
cubeMapper.SetInputData(cube)
cubeActor = vtkActor()
cubeActor.SetMapper(cubeMapper)
# Interpolate some transformations, test along the way
interpolator = vtkTransformInterpolator()
#interpolator SetInterpolationTypeToLinear
interpolator.SetInterpolationTypeToSpline()
interpolator.AddTransform(0.0,cube1)
interpolator.AddTransform(8.0,cube2)
interpolator.AddTransform(18.2,cube3)
interpolator.AddTransform(24.4,cube4)
interpolator.Initialize()
#puts [interpolator GetNumberOfTransforms]
interpolator.AddTransform(0.0,t1)
interpolator.AddTransform(8.0,t2)
interpolator.AddTransform(18.2,t3)
interpolator.AddTransform(24.4,t4)
#puts [interpolator GetNumberOfTransforms]
# Create the RenderWindow, Renderer and both Actors
#
ren1 = vtkRenderer()
renWin = vtkRenderWindow()
renWin.AddRenderer(ren1)
iren = vtkRenderWindowInteractor()
iren.SetRenderWindow(renWin)
# Add the actors to the renderer, set the background and size
#
ren1.AddActor(cube1)
ren1.AddActor(cube2)
ren1.AddActor(cube3)
ren1.AddActor(cube4)
ren1.AddActor(cubeActor)
ren1.SetBackground(0,0,0)
renWin.SetSize(300,300)
ren1.SetBackground(0.1,0.2,0.4)
# render the image
#
camera = vtkCamera()
camera.SetClippingRange(31.2977,81.697)
camera.SetFocalPoint(3.0991,-2.00445,9.78648)
camera.SetPosition(-44.8481,-25.871,10.0645)
camera.SetViewAngle(30)
camera.SetViewUp(-0.0356378,0.0599728,-0.997564)
ren1.SetActiveCamera(camera)
renWin.Render()
# prevent the tk window from showing up then start the event loop
xform = vtkTransform()
def animate():
    numSteps = 250
    min = interpolator.GetMinimumT()
    max = interpolator.GetMaximumT()
    i = 0
    while i <= numSteps:
        t = float(i)*(max-min)/float(numSteps)
        interpolator.InterpolateTransform(t,xform)
        cubeActor.SetUserMatrix(xform.GetMatrix())
        renWin.Render()
        i = i + 1


interpolator.InterpolateTransform(13.2,xform)
cubeActor.SetUserMatrix(xform.GetMatrix())
renWin.Render()
#animate()
# --- end of script --



#!/usr/bin/env python
from vtkmodules.vtkCommonTransforms import vtkTransform
from vtkmodules.vtkFiltersCore import (
    vtkAppendPolyData,
    vtkContourFilter,
    vtkProbeFilter,
    vtkStructuredGridOutlineFilter,
)
from vtkmodules.vtkFiltersGeneral import vtkTransformPolyDataFilter
from vtkmodules.vtkFiltersModeling import vtkOutlineFilter
from vtkmodules.vtkFiltersSources import vtkPlaneSource
from vtkmodules.vtkIOParallel import vtkMultiBlockPLOT3DReader
from vtkmodules.vtkRenderingCore import (
    vtkActor,
    vtkPolyDataMapper,
    vtkRenderWindow,
    vtkRenderWindowInteractor,
    vtkRenderer,
)
import vtkmodules.vtkInteractionStyle
import vtkmodules.vtkRenderingFreeType
import vtkmodules.vtkRenderingOpenGL2
from vtkmodules.util.misc import vtkGetDataRoot
VTK_DATA_ROOT = vtkGetDataRoot()

# create planes
# Create the RenderWindow, Renderer and both Actors
#
ren1 = vtkRenderer()
renWin = vtkRenderWindow()
renWin.SetMultiSamples(0)
renWin.AddRenderer(ren1)
iren = vtkRenderWindowInteractor()
iren.SetRenderWindow(renWin)
# create pipeline
#
pl3d = vtkMultiBlockPLOT3DReader()
pl3d.SetXYZFileName(VTK_DATA_ROOT + "/Data/combxyz.bin")
pl3d.SetQFileName(VTK_DATA_ROOT + "/Data/combq.bin")
pl3d.SetScalarFunctionNumber(100)
pl3d.SetVectorFunctionNumber(202)
pl3d.Update()
output = pl3d.GetOutput().GetBlock(0)
plane = vtkPlaneSource()
plane.SetResolution(50,50)
transP1 = vtkTransform()
transP1.Translate(3.7,0.0,28.37)
transP1.Scale(5,5,5)
transP1.RotateY(90)
tpd1 = vtkTransformPolyDataFilter()
tpd1.SetInputConnection(plane.GetOutputPort())
tpd1.SetTransform(transP1)
outTpd1 = vtkOutlineFilter()
outTpd1.SetInputConnection(tpd1.GetOutputPort())
mapTpd1 = vtkPolyDataMapper()
mapTpd1.SetInputConnection(outTpd1.GetOutputPort())
tpd1Actor = vtkActor()
tpd1Actor.SetMapper(mapTpd1)
tpd1Actor.GetProperty().SetColor(0,0,0)
transP2 = vtkTransform()
transP2.Translate(9.2,0.0,31.20)
transP2.Scale(5,5,5)
transP2.RotateY(90)
tpd2 = vtkTransformPolyDataFilter()
tpd2.SetInputConnection(plane.GetOutputPort())
tpd2.SetTransform(transP2)
outTpd2 = vtkOutlineFilter()
outTpd2.SetInputConnection(tpd2.GetOutputPort())
mapTpd2 = vtkPolyDataMapper()
mapTpd2.SetInputConnection(outTpd2.GetOutputPort())
tpd2Actor = vtkActor()
tpd2Actor.SetMapper(mapTpd2)
tpd2Actor.GetProperty().SetColor(0,0,0)
transP3 = vtkTransform()
transP3.Translate(13.27,0.0,33.30)
transP3.Scale(5,5,5)
transP3.RotateY(90)
tpd3 = vtkTransformPolyDataFilter()
tpd3.SetInputConnection(plane.GetOutputPort())
tpd3.SetTransform(transP3)
outTpd3 = vtkOutlineFilter()
outTpd3.SetInputConnection(tpd3.GetOutputPort())
mapTpd3 = vtkPolyDataMapper()
mapTpd3.SetInputConnection(outTpd3.GetOutputPort())
tpd3Actor = vtkActor()
tpd3Actor.SetMapper(mapTpd3)
tpd3Actor.GetProperty().SetColor(0,0,0)
appendF = vtkAppendPolyData()
appendF.AddInputConnection(tpd1.GetOutputPort())
appendF.AddInputConnection(tpd2.GetOutputPort())
appendF.AddInputConnection(tpd3.GetOutputPort())
probe = vtkProbeFilter()
probe.SetInputConnection(appendF.GetOutputPort())
probe.SetSourceData(output)
contour = vtkContourFilter()
contour.SetInputConnection(probe.GetOutputPort())
contour.GenerateValues(50,output.GetScalarRange())
contourMapper = vtkPolyDataMapper()
contourMapper.SetInputConnection(contour.GetOutputPort())
contourMapper.SetScalarRange(output.GetScalarRange())
planeActor = vtkActor()
planeActor.SetMapper(contourMapper)
outline = vtkStructuredGridOutlineFilter()
outline.SetInputData(output)
outlineMapper = vtkPolyDataMapper()
outlineMapper.SetInputConnection(outline.GetOutputPort())
outlineActor = vtkActor()
outlineActor.SetMapper(outlineMapper)
outlineActor.GetProperty().SetColor(0,0,0)
ren1.AddActor(outlineActor)
ren1.AddActor(planeActor)
ren1.AddActor(tpd1Actor)
ren1.AddActor(tpd2Actor)
ren1.AddActor(tpd3Actor)
ren1.SetBackground(1,1,1)
renWin.SetSize(400,400)
cam1 = ren1.GetActiveCamera()
cam1.SetClippingRange(3.95297,50)
cam1.SetFocalPoint(8.88908,0.595038,29.3342)
cam1.SetPosition(-12.3332,31.7479,41.2387)
cam1.SetViewUp(0.060772,-0.319905,0.945498)
iren.Initialize()
renWin.Render()
iren.Start()
# --- end of script --



#!/usr/bin/env python
from vtkmodules.vtkIOImage import vtkTIFFReader
from vtkmodules.vtkIOParallel import vtkPImageWriter
from vtkmodules.vtkInteractionImage import vtkImageViewer
import vtkmodules.vtkInteractionStyle
import vtkmodules.vtkRenderingFreeType
import vtkmodules.vtkRenderingOpenGL2
from vtkmodules.util.misc import vtkGetDataRoot
import os

VTK_DATA_ROOT = vtkGetDataRoot()

# Image pipeline
image1 = vtkTIFFReader()
image1.SetFileName(VTK_DATA_ROOT + "/Data/beach.tif")
# "beach.tif" image contains ORIENTATION tag which is
# ORIENTATION_TOPLEFT (row 0 top, col 0 lhs) type. The TIFF
# reader parses this tag and sets the internal TIFF image
# orientation accordingly.  To overwrite this orientation with a vtk
# convention of ORIENTATION_BOTLEFT (row 0 bottom, col 0 lhs ), invoke
# SetOrientationType method with parameter value of 4.
image1.SetOrientationType(4)
image1.Update()
#
# If the current directory is writable, then test the writers
#
if os.access('.', os.W_OK):
    piw = vtkPImageWriter()
    piw.SetInputConnection(image1.GetOutputPort())
    piw.SetFileName('piw.raw')
    piw.SetMemoryLimit(1)
    piw.Write()
    os.remove('piw.raw')
viewer = vtkImageViewer()
viewer.SetInputConnection(image1.GetOutputPort())
viewer.SetColorWindow(255)
viewer.SetColorLevel(127.5)
viewer.Render()
# --- end of script --



#!/usr/bin/env python
# -*- coding: utf-8 -*-



import os
from vtkmodules.vtkCommonCore import (
    vtkFloatArray,
    vtkPoints,
)
from vtkmodules.vtkCommonDataModel import (
    vtkHexagonalPrism,
    vtkHexahedron,
    vtkLine,
    vtkPentagonalPrism,
    vtkPixel,
    vtkPolyLine,
    vtkPolyVertex,
    vtkPolygon,
    vtkPyramid,
    vtkQuad,
    vtkTetra,
    vtkTriangle,
    vtkTriangleStrip,
    vtkUnstructuredGrid,
    vtkVertex,
    vtkVoxel,
    vtkWedge,
)
from vtkmodules.vtkIOImage import vtkBMPReader
from vtkmodules.vtkRenderingCore import (
    vtkActor,
    vtkDataSetMapper,
    vtkLight,
    vtkProperty,
    vtkRenderWindow,
    vtkRenderWindowInteractor,
    vtkRenderer,
    vtkTexture,
)
import vtkmodules.vtkInteractionStyle
import vtkmodules.vtkRenderingFreeType
import vtkmodules.vtkRenderingOpenGL2
import vtkmodules.test.Testing
from vtkmodules.util.misc import vtkGetDataRoot,vtkGetTempDir
VTK_DATA_ROOT = vtkGetDataRoot()
VTK_TEMP_DIR = vtkGetTempDir()

if 'vtkIOExport' in vtkmodules.__all__:
    from vtkmodules.vtkIOExport import (
        vtkIVExporter,
        vtkOBJExporter,
        vtkOOGLExporter,
        vtkRIBExporter,
        vtkRIBLight,
        vtkRIBProperty,
        vtkVRMLExporter,
    )
    vtk_has_IOExport = True
else:
    vtk_has_IOExport = False

class cells(vtkmodules.test.Testing.vtkTest):

    def testCells(self):

        # Demonstrates all cell types
        #
        # NOTE: the use of NewInstance/DeepCopy is included to increase
        # regression coverage.  It is not required in most applications.

        ren = vtkRenderer()
        # turn off all cullers
        ren.GetCullers().RemoveAllItems()

        renWin = vtkRenderWindow()
        renWin.AddRenderer(ren)
        renWin.SetSize(300, 150)
        iRen = vtkRenderWindowInteractor()
        iRen.SetRenderWindow(renWin);

        # create a scene with one of each cell type

        # Voxel

        voxelPoints = vtkPoints()
        voxelPoints.SetNumberOfPoints(8)
        voxelPoints.InsertPoint(0, 0, 0, 0)
        voxelPoints.InsertPoint(1, 1, 0, 0)
        voxelPoints.InsertPoint(2, 0, 1, 0)
        voxelPoints.InsertPoint(3, 1, 1, 0)
        voxelPoints.InsertPoint(4, 0, 0, 1)
        voxelPoints.InsertPoint(5, 1, 0, 1)
        voxelPoints.InsertPoint(6, 0, 1, 1)
        voxelPoints.InsertPoint(7, 1, 1, 1)

        aVoxel = vtkVoxel()
        aVoxel.GetPointIds().SetId(0, 0)
        aVoxel.GetPointIds().SetId(1, 1)
        aVoxel.GetPointIds().SetId(2, 2)
        aVoxel.GetPointIds().SetId(3, 3)
        aVoxel.GetPointIds().SetId(4, 4)
        aVoxel.GetPointIds().SetId(5, 5)
        aVoxel.GetPointIds().SetId(6, 6)
        aVoxel.GetPointIds().SetId(7, 7)

        bVoxel = aVoxel.NewInstance()
        bVoxel.DeepCopy(aVoxel)

        aVoxelGrid = vtkUnstructuredGrid()
        aVoxelGrid.Allocate(1, 1)
        aVoxelGrid.InsertNextCell(aVoxel.GetCellType(), aVoxel.GetPointIds())
        aVoxelGrid.SetPoints(voxelPoints)

        aVoxelMapper = vtkDataSetMapper()
        aVoxelMapper.SetInputData(aVoxelGrid)

        aVoxelActor = vtkActor()
        aVoxelActor.SetMapper(aVoxelMapper)
        aVoxelActor.GetProperty().BackfaceCullingOn()

        # Hexahedron

        hexahedronPoints = vtkPoints()
        hexahedronPoints.SetNumberOfPoints(8)
        hexahedronPoints.InsertPoint(0, 0, 0, 0)
        hexahedronPoints.InsertPoint(1, 1, 0, 0)
        hexahedronPoints.InsertPoint(2, 1, 1, 0)
        hexahedronPoints.InsertPoint(3, 0, 1, 0)
        hexahedronPoints.InsertPoint(4, 0, 0, 1)
        hexahedronPoints.InsertPoint(5, 1, 0, 1)
        hexahedronPoints.InsertPoint(6, 1, 1, 1)
        hexahedronPoints.InsertPoint(7, 0, 1, 1)

        aHexahedron = vtkHexahedron()
        aHexahedron.GetPointIds().SetId(0, 0)
        aHexahedron.GetPointIds().SetId(1, 1)
        aHexahedron.GetPointIds().SetId(2, 2)
        aHexahedron.GetPointIds().SetId(3, 3)
        aHexahedron.GetPointIds().SetId(4, 4)
        aHexahedron.GetPointIds().SetId(5, 5)
        aHexahedron.GetPointIds().SetId(6, 6)
        aHexahedron.GetPointIds().SetId(7, 7)

        bHexahedron = aHexahedron.NewInstance()
        bHexahedron.DeepCopy(aHexahedron)

        aHexahedronGrid = vtkUnstructuredGrid()
        aHexahedronGrid.Allocate(1, 1)
        aHexahedronGrid.InsertNextCell(aHexahedron.GetCellType(), aHexahedron.GetPointIds())
        aHexahedronGrid.SetPoints(hexahedronPoints)

        aHexahedronMapper = vtkDataSetMapper()
        aHexahedronMapper.SetInputData(aHexahedronGrid)

        aHexahedronActor = vtkActor()
        aHexahedronActor.SetMapper(aHexahedronMapper)
        aHexahedronActor.AddPosition(2, 0, 0)
        aHexahedronActor.GetProperty().BackfaceCullingOn()

        # Tetra

        tetraPoints = vtkPoints()
        tetraPoints.SetNumberOfPoints(4)
        tetraPoints.InsertPoint(0, 0, 0, 0)
        tetraPoints.InsertPoint(1, 1, 0, 0)
        tetraPoints.InsertPoint(2, .5, 1, 0)
        tetraPoints.InsertPoint(3, .5, .5, 1)

        aTetra = vtkTetra()
        aTetra.GetPointIds().SetId(0, 0)
        aTetra.GetPointIds().SetId(1, 1)
        aTetra.GetPointIds().SetId(2, 2)
        aTetra.GetPointIds().SetId(3, 3)

        bTetra = aTetra.NewInstance()
        bTetra.DeepCopy(aTetra)

        aTetraGrid = vtkUnstructuredGrid()
        aTetraGrid.Allocate(1, 1)
        aTetraGrid.InsertNextCell(aTetra.GetCellType(), aTetra.GetPointIds())
        aTetraGrid.SetPoints(tetraPoints)

        aTetraCopy = vtkUnstructuredGrid()
        aTetraCopy.ShallowCopy(aTetraGrid)

        aTetraMapper = vtkDataSetMapper()
        aTetraMapper.SetInputData(aTetraCopy)

        aTetraActor = vtkActor()
        aTetraActor.SetMapper(aTetraMapper)
        aTetraActor.AddPosition(4, 0, 0)
        aTetraActor.GetProperty().BackfaceCullingOn()

        # Wedge

        wedgePoints = vtkPoints()
        wedgePoints.SetNumberOfPoints(6)
        wedgePoints.InsertPoint(0, 0, 1, 0)
        wedgePoints.InsertPoint(1, 0, 0, 0)
        wedgePoints.InsertPoint(2, 0, .5, .5)
        wedgePoints.InsertPoint(3, 1, 1, 0)
        wedgePoints.InsertPoint(4, 1, 0, 0)
        wedgePoints.InsertPoint(5, 1, .5, .5)

        aWedge = vtkWedge()
        aWedge.GetPointIds().SetId(0, 0)
        aWedge.GetPointIds().SetId(1, 1)
        aWedge.GetPointIds().SetId(2, 2)
        aWedge.GetPointIds().SetId(3, 3)
        aWedge.GetPointIds().SetId(4, 4)
        aWedge.GetPointIds().SetId(5, 5)

        bWedge = aWedge.NewInstance()
        bWedge.DeepCopy(aWedge)

        aWedgeGrid = vtkUnstructuredGrid()
        aWedgeGrid.Allocate(1, 1)
        aWedgeGrid.InsertNextCell(aWedge.GetCellType(), aWedge.GetPointIds())
        aWedgeGrid.SetPoints(wedgePoints)

        aWedgeCopy = vtkUnstructuredGrid()
        aWedgeCopy.DeepCopy(aWedgeGrid)

        aWedgeMapper = vtkDataSetMapper()
        aWedgeMapper.SetInputData(aWedgeCopy)

        aWedgeActor = vtkActor()
        aWedgeActor.SetMapper(aWedgeMapper)
        aWedgeActor.AddPosition(6, 0, 0)
        aWedgeActor.GetProperty().BackfaceCullingOn()

        # Pyramid

        pyramidPoints = vtkPoints()
        pyramidPoints.SetNumberOfPoints(5)
        pyramidPoints.InsertPoint(0, 0, 0, 0)
        pyramidPoints.InsertPoint(1, 1, 0, 0)
        pyramidPoints.InsertPoint(2, 1, 1, 0)
        pyramidPoints.InsertPoint(3, 0, 1, 0)
        pyramidPoints.InsertPoint(4, .5, .5, 1)

        aPyramid = vtkPyramid()
        aPyramid.GetPointIds().SetId(0, 0)
        aPyramid.GetPointIds().SetId(1, 1)
        aPyramid.GetPointIds().SetId(2, 2)
        aPyramid.GetPointIds().SetId(3, 3)
        aPyramid.GetPointIds().SetId(4, 4)

        bPyramid = aPyramid.NewInstance()
        bPyramid.DeepCopy(aPyramid)

        aPyramidGrid = vtkUnstructuredGrid()
        aPyramidGrid.Allocate(1, 1)
        aPyramidGrid.InsertNextCell(aPyramid.GetCellType(), aPyramid.GetPointIds())
        aPyramidGrid.SetPoints(pyramidPoints)

        aPyramidMapper = vtkDataSetMapper()
        aPyramidMapper.SetInputData(aPyramidGrid)

        aPyramidActor = vtkActor()
        aPyramidActor.SetMapper(aPyramidMapper)
        aPyramidActor.AddPosition(8, 0, 0)
        aPyramidActor.GetProperty().BackfaceCullingOn()

        # Pixel

        pixelPoints = vtkPoints()
        pixelPoints.SetNumberOfPoints(4)
        pixelPoints.InsertPoint(0, 0, 0, 0)
        pixelPoints.InsertPoint(1, 1, 0, 0)
        pixelPoints.InsertPoint(2, 0, 1, 0)
        pixelPoints.InsertPoint(3, 1, 1, 0)

        aPixel = vtkPixel()
        aPixel.GetPointIds().SetId(0, 0)
        aPixel.GetPointIds().SetId(1, 1)
        aPixel.GetPointIds().SetId(2, 2)
        aPixel.GetPointIds().SetId(3, 3)

        bPixel = aPixel.NewInstance()
        bPixel.DeepCopy(aPixel)

        aPixelGrid = vtkUnstructuredGrid()
        aPixelGrid.Allocate(1, 1)
        aPixelGrid.InsertNextCell(aPixel.GetCellType(), aPixel.GetPointIds())
        aPixelGrid.SetPoints(pixelPoints)

        aPixelMapper = vtkDataSetMapper()
        aPixelMapper.SetInputData(aPixelGrid)

        aPixelActor = vtkActor()
        aPixelActor.SetMapper(aPixelMapper)
        aPixelActor.AddPosition(0, 0, 2)
        aPixelActor.GetProperty().BackfaceCullingOn()

        # Quad

        quadPoints = vtkPoints()
        quadPoints.SetNumberOfPoints(4)
        quadPoints.InsertPoint(0, 0, 0, 0)
        quadPoints.InsertPoint(1, 1, 0, 0)
        quadPoints.InsertPoint(2, 1, 1, 0)
        quadPoints.InsertPoint(3, 0, 1, 0)

        aQuad = vtkQuad()
        aQuad.GetPointIds().SetId(0, 0)
        aQuad.GetPointIds().SetId(1, 1)
        aQuad.GetPointIds().SetId(2, 2)
        aQuad.GetPointIds().SetId(3, 3)

        bQuad = aQuad.NewInstance()
        bQuad.DeepCopy(aQuad)

        aQuadGrid = vtkUnstructuredGrid()
        aQuadGrid.Allocate(1, 1)
        aQuadGrid.InsertNextCell(aQuad.GetCellType(), aQuad.GetPointIds())
        aQuadGrid.SetPoints(quadPoints)

        aQuadMapper = vtkDataSetMapper()
        aQuadMapper.SetInputData(aQuadGrid)

        aQuadActor = vtkActor()
        aQuadActor.SetMapper(aQuadMapper)
        aQuadActor.AddPosition(2, 0, 2)
        aQuadActor.GetProperty().BackfaceCullingOn()

        # Triangle

        trianglePoints = vtkPoints()
        trianglePoints.SetNumberOfPoints(3)
        trianglePoints.InsertPoint(0, 0, 0, 0)
        trianglePoints.InsertPoint(1, 1, 0, 0)
        trianglePoints.InsertPoint(2, .5, .5, 0)

        triangleTCoords = vtkFloatArray()
        triangleTCoords.SetNumberOfComponents(2)
        triangleTCoords.SetNumberOfTuples(3)
        triangleTCoords.InsertTuple2(0, 1, 1)
        triangleTCoords.InsertTuple2(1, 2, 2)
        triangleTCoords.InsertTuple2(2, 3, 3)

        aTriangle = vtkTriangle()
        aTriangle.GetPointIds().SetId(0, 0)
        aTriangle.GetPointIds().SetId(1, 1)
        aTriangle.GetPointIds().SetId(2, 2)

        bTriangle = aTriangle.NewInstance()
        bTriangle.DeepCopy(aTriangle)

        aTriangleGrid = vtkUnstructuredGrid()
        aTriangleGrid.Allocate(1, 1)
        aTriangleGrid.InsertNextCell(aTriangle.GetCellType(), aTriangle.GetPointIds())
        aTriangleGrid.SetPoints(trianglePoints)
        aTriangleGrid.GetPointData().SetTCoords(triangleTCoords)

        aTriangleMapper = vtkDataSetMapper()
        aTriangleMapper.SetInputData(aTriangleGrid)

        aTriangleActor = vtkActor()
        aTriangleActor.SetMapper(aTriangleMapper)
        aTriangleActor.AddPosition(4, 0, 2)
        aTriangleActor.GetProperty().BackfaceCullingOn()

        # Polygon

        polygonPoints = vtkPoints()
        polygonPoints.SetNumberOfPoints(4)
        polygonPoints.InsertPoint(0, 0, 0, 0)
        polygonPoints.InsertPoint(1, 1, 0, 0)
        polygonPoints.InsertPoint(2, 1, 1, 0)
        polygonPoints.InsertPoint(3, 0, 1, 0)

        aPolygon = vtkPolygon()
        aPolygon.GetPointIds().SetNumberOfIds(4)
        aPolygon.GetPointIds().SetId(0, 0)
        aPolygon.GetPointIds().SetId(1, 1)
        aPolygon.GetPointIds().SetId(2, 2)
        aPolygon.GetPointIds().SetId(3, 3)

        bPolygon = aPolygon.NewInstance()
        bPolygon.DeepCopy(aPolygon)

        aPolygonGrid = vtkUnstructuredGrid()
        aPolygonGrid.Allocate(1, 1)
        aPolygonGrid.InsertNextCell(aPolygon.GetCellType(), aPolygon.GetPointIds())
        aPolygonGrid.SetPoints(polygonPoints)

        aPolygonMapper = vtkDataSetMapper()
        aPolygonMapper.SetInputData(aPolygonGrid)

        aPolygonActor = vtkActor()
        aPolygonActor.SetMapper(aPolygonMapper)
        aPolygonActor.AddPosition(6, 0, 2)
        aPolygonActor.GetProperty().BackfaceCullingOn()

        # Triangle Strip

        triangleStripPoints = vtkPoints()
        triangleStripPoints.SetNumberOfPoints(5)
        triangleStripPoints.InsertPoint(0, 0, 1, 0)
        triangleStripPoints.InsertPoint(1, 0, 0, 0)
        triangleStripPoints.InsertPoint(2, 1, 1, 0)
        triangleStripPoints.InsertPoint(3, 1, 0, 0)
        triangleStripPoints.InsertPoint(4, 2, 1, 0)

        triangleStripTCoords = vtkFloatArray()
        triangleStripTCoords.SetNumberOfComponents(2)
        triangleStripTCoords.SetNumberOfTuples(3)
        triangleStripTCoords.InsertTuple2(0, 1, 1)
        triangleStripTCoords.InsertTuple2(1, 2, 2)
        triangleStripTCoords.InsertTuple2(2, 3, 3)
        triangleStripTCoords.InsertTuple2(3, 4, 4)
        triangleStripTCoords.InsertTuple2(4, 5, 5)

        aTriangleStrip = vtkTriangleStrip()
        aTriangleStrip.GetPointIds().SetNumberOfIds(5)
        aTriangleStrip.GetPointIds().SetId(0, 0)
        aTriangleStrip.GetPointIds().SetId(1, 1)
        aTriangleStrip.GetPointIds().SetId(2, 2)
        aTriangleStrip.GetPointIds().SetId(3, 3)
        aTriangleStrip.GetPointIds().SetId(4, 4)

        bTriangleStrip = aTriangleStrip.NewInstance()
        bTriangleStrip.DeepCopy(aTriangleStrip)

        aTriangleStripGrid = vtkUnstructuredGrid()
        aTriangleStripGrid.Allocate(1, 1)
        aTriangleStripGrid.InsertNextCell(aTriangleStrip.GetCellType(), aTriangleStrip.GetPointIds())
        aTriangleStripGrid.SetPoints(triangleStripPoints)
        aTriangleStripGrid.GetPointData().SetTCoords(triangleStripTCoords)

        aTriangleStripMapper = vtkDataSetMapper()
        aTriangleStripMapper.SetInputData(aTriangleStripGrid)

        aTriangleStripActor = vtkActor()
        aTriangleStripActor.SetMapper(aTriangleStripMapper)
        aTriangleStripActor.AddPosition(8, 0, 2)
        aTriangleStripActor.GetProperty().BackfaceCullingOn()

        # Line

        linePoints = vtkPoints()
        linePoints.SetNumberOfPoints(2)
        linePoints.InsertPoint(0, 0, 0, 0)
        linePoints.InsertPoint(1, 1, 1, 0)

        aLine = vtkLine()
        aLine.GetPointIds().SetId(0, 0)
        aLine.GetPointIds().SetId(1, 1)

        bLine = aLine.NewInstance()
        bLine.DeepCopy(aLine)

        aLineGrid = vtkUnstructuredGrid()
        aLineGrid.Allocate(1, 1)
        aLineGrid.InsertNextCell(aLine.GetCellType(), aLine.GetPointIds())
        aLineGrid.SetPoints(linePoints)

        aLineMapper = vtkDataSetMapper()
        aLineMapper.SetInputData(aLineGrid)

        aLineActor = vtkActor()
        aLineActor.SetMapper(aLineMapper)
        aLineActor.AddPosition(0, 0, 4)
        aLineActor.GetProperty().BackfaceCullingOn()

        # Poly line

        polyLinePoints = vtkPoints()
        polyLinePoints.SetNumberOfPoints(3)
        polyLinePoints.InsertPoint(0, 0, 0, 0)
        polyLinePoints.InsertPoint(1, 1, 1, 0)
        polyLinePoints.InsertPoint(2, 1, 0, 0)

        aPolyLine = vtkPolyLine()
        aPolyLine.GetPointIds().SetNumberOfIds(3)
        aPolyLine.GetPointIds().SetId(0, 0)
        aPolyLine.GetPointIds().SetId(1, 1)
        aPolyLine.GetPointIds().SetId(2, 2)

        bPolyLine = aPolyLine.NewInstance()
        bPolyLine.DeepCopy(aPolyLine)

        aPolyLineGrid = vtkUnstructuredGrid()
        aPolyLineGrid.Allocate(1, 1)
        aPolyLineGrid.InsertNextCell(aPolyLine.GetCellType(), aPolyLine.GetPointIds())
        aPolyLineGrid.SetPoints(polyLinePoints)

        aPolyLineMapper = vtkDataSetMapper()
        aPolyLineMapper.SetInputData(aPolyLineGrid)

        aPolyLineActor = vtkActor()
        aPolyLineActor.SetMapper(aPolyLineMapper)
        aPolyLineActor.AddPosition(2, 0, 4)
        aPolyLineActor.GetProperty().BackfaceCullingOn()

        # Vertex

        vertexPoints = vtkPoints()
        vertexPoints.SetNumberOfPoints(1)
        vertexPoints.InsertPoint(0, 0, 0, 0)

        aVertex = vtkVertex()
        aVertex.GetPointIds().SetId(0, 0)

        bVertex = aVertex.NewInstance()
        bVertex.DeepCopy(aVertex)

        aVertexGrid = vtkUnstructuredGrid()
        aVertexGrid.Allocate(1, 1)
        aVertexGrid.InsertNextCell(aVertex.GetCellType(), aVertex.GetPointIds())
        aVertexGrid.SetPoints(vertexPoints)

        aVertexMapper = vtkDataSetMapper()
        aVertexMapper.SetInputData(aVertexGrid)

        aVertexActor = vtkActor()
        aVertexActor.SetMapper(aVertexMapper)
        aVertexActor.AddPosition(0, 0, 6)
        aVertexActor.GetProperty().BackfaceCullingOn()

        # Poly Vertex

        polyVertexPoints = vtkPoints()
        polyVertexPoints.SetNumberOfPoints(3)
        polyVertexPoints.InsertPoint(0, 0, 0, 0)
        polyVertexPoints.InsertPoint(1, 1, 0, 0)
        polyVertexPoints.InsertPoint(2, 1, 1, 0)

        aPolyVertex = vtkPolyVertex()
        aPolyVertex.GetPointIds().SetNumberOfIds(3)
        aPolyVertex.GetPointIds().SetId(0, 0)
        aPolyVertex.GetPointIds().SetId(1, 1)
        aPolyVertex.GetPointIds().SetId(2, 2)

        bPolyVertex = aPolyVertex.NewInstance()
        bPolyVertex.DeepCopy(aPolyVertex)

        aPolyVertexGrid = vtkUnstructuredGrid()
        aPolyVertexGrid.Allocate(1, 1)
        aPolyVertexGrid.InsertNextCell(aPolyVertex.GetCellType(), aPolyVertex.GetPointIds())
        aPolyVertexGrid.SetPoints(polyVertexPoints)

        aPolyVertexMapper = vtkDataSetMapper()
        aPolyVertexMapper.SetInputData(aPolyVertexGrid)

        aPolyVertexActor = vtkActor()
        aPolyVertexActor.SetMapper(aPolyVertexMapper)
        aPolyVertexActor.AddPosition(2, 0, 6)
        aPolyVertexActor.GetProperty().BackfaceCullingOn()

        # Pentagonal prism

        pentaPoints = vtkPoints()
        pentaPoints.SetNumberOfPoints(10)
        pentaPoints.InsertPoint(0, 0.25, 0.0, 0.0)
        pentaPoints.InsertPoint(1, 0.75, 0.0, 0.0)
        pentaPoints.InsertPoint(2, 1.0, 0.5, 0.0)
        pentaPoints.InsertPoint(3, 0.5, 1.0, 0.0)
        pentaPoints.InsertPoint(4, 0.0, 0.5, 0.0)
        pentaPoints.InsertPoint(5, 0.25, 0.0, 1.0)
        pentaPoints.InsertPoint(6, 0.75, 0.0, 1.0)
        pentaPoints.InsertPoint(7, 1.0, 0.5, 1.0)
        pentaPoints.InsertPoint(8, 0.5, 1.0, 1.0)
        pentaPoints.InsertPoint(9, 0.0, 0.5, 1.0)

        aPenta = vtkPentagonalPrism()
        aPenta.GetPointIds().SetId(0, 0)
        aPenta.GetPointIds().SetId(1, 1)
        aPenta.GetPointIds().SetId(2, 2)
        aPenta.GetPointIds().SetId(3, 3)
        aPenta.GetPointIds().SetId(4, 4)
        aPenta.GetPointIds().SetId(5, 5)
        aPenta.GetPointIds().SetId(6, 6)
        aPenta.GetPointIds().SetId(7, 7)
        aPenta.GetPointIds().SetId(8, 8)
        aPenta.GetPointIds().SetId(9, 9)

        bPenta = aPenta.NewInstance()
        bPenta.DeepCopy(aPenta)

        aPentaGrid = vtkUnstructuredGrid()
        aPentaGrid.Allocate(1, 1)
        aPentaGrid.InsertNextCell(aPenta.GetCellType(), aPenta.GetPointIds())
        aPentaGrid.SetPoints(pentaPoints)

        aPentaCopy = vtkUnstructuredGrid()
        aPentaCopy.DeepCopy(aPentaGrid)

        aPentaMapper = vtkDataSetMapper()
        aPentaMapper.SetInputData(aPentaCopy)

        aPentaActor = vtkActor()
        aPentaActor.SetMapper(aPentaMapper)
        aPentaActor.AddPosition(10, 0, 0)
        aPentaActor.GetProperty().BackfaceCullingOn()

        # Hexagonal prism

        hexaPoints = vtkPoints()
        hexaPoints.SetNumberOfPoints(12)
        hexaPoints.InsertPoint(0, 0.0, 0.0, 0.0)
        hexaPoints.InsertPoint(1, 0.5, 0.0, 0.0)
        hexaPoints.InsertPoint(2, 1.0, 0.5, 0.0)
        hexaPoints.InsertPoint(3, 1.0, 1.0, 0.0)
        hexaPoints.InsertPoint(4, 0.5, 1.0, 0.0)
        hexaPoints.InsertPoint(5, 0.0, 0.5, 0.0)
        hexaPoints.InsertPoint(6, 0.0, 0.0, 1.0)
        hexaPoints.InsertPoint(7, 0.5, 0.0, 1.0)
        hexaPoints.InsertPoint(8, 1.0, 0.5, 1.0)
        hexaPoints.InsertPoint(9, 1.0, 1.0, 1.0)
        hexaPoints.InsertPoint(10, 0.5, 1.0, 1.0)
        hexaPoints.InsertPoint(11, 0.0, 0.5, 1.0)

        aHexa = vtkHexagonalPrism()
        aHexa.GetPointIds().SetId(0, 0)
        aHexa.GetPointIds().SetId(1, 1)
        aHexa.GetPointIds().SetId(2, 2)
        aHexa.GetPointIds().SetId(3, 3)
        aHexa.GetPointIds().SetId(4, 4)
        aHexa.GetPointIds().SetId(5, 5)
        aHexa.GetPointIds().SetId(6, 6)
        aHexa.GetPointIds().SetId(7, 7)
        aHexa.GetPointIds().SetId(8, 8)
        aHexa.GetPointIds().SetId(9, 9)
        aHexa.GetPointIds().SetId(10, 10)
        aHexa.GetPointIds().SetId(11, 11)

        bHexa = aHexa.NewInstance()
        bHexa.DeepCopy(aHexa)

        aHexaGrid = vtkUnstructuredGrid()
        aHexaGrid.Allocate(1, 1)
        aHexaGrid.InsertNextCell(aHexa.GetCellType(), aHexa.GetPointIds())
        aHexaGrid.SetPoints(hexaPoints)

        aHexaCopy = vtkUnstructuredGrid()
        aHexaCopy.DeepCopy(aHexaGrid)

        aHexaMapper = vtkDataSetMapper()
        aHexaMapper.SetInputData(aHexaCopy)

        aHexaActor = vtkActor()
        aHexaActor.SetMapper(aHexaMapper)
        aHexaActor.AddPosition(12, 0, 0)
        aHexaActor.GetProperty().BackfaceCullingOn()

        # RIB property
        if vtk_has_IOExport:
            aRIBProperty = vtkRIBProperty()
            aRIBProperty.SetVariable("Km", "float")
            aRIBProperty.SetSurfaceShader("LGVeinedmarble")
            aRIBProperty.SetVariable("veinfreq", "float")
            aRIBProperty.AddVariable("warpfreq", "float")
            aRIBProperty.AddVariable("veincolor", "color")
            aRIBProperty.AddSurfaceShaderParameter("veinfreq", " 2")
            aRIBProperty.AddSurfaceShaderParameter("veincolor", "1.0000 1.0000 0.9412")
            bRIBProperty = vtkRIBProperty()
            bRIBProperty.SetVariable("Km", "float")
            bRIBProperty.SetSurfaceShaderParameter("Km", "1.0")
            bRIBProperty.SetDisplacementShader("dented")
            bRIBProperty.SetSurfaceShader("plastic")

        aProperty = vtkProperty()
        bProperty = vtkProperty()

        aTriangleActor.SetProperty(aProperty)
        aTriangleStripActor.SetProperty(bProperty)

        ren.SetBackground(.1, .2, .4)

        ren.AddActor(aVoxelActor);aVoxelActor.GetProperty().SetDiffuseColor(1, 0, 0)
        ren.AddActor(aHexahedronActor);aHexahedronActor.GetProperty().SetDiffuseColor(1, 1, 0)
        ren.AddActor(aTetraActor);aTetraActor.GetProperty().SetDiffuseColor(0, 1, 0)
        ren.AddActor(aWedgeActor);aWedgeActor.GetProperty().SetDiffuseColor(0, 1, 1)
        ren.AddActor(aPyramidActor);aPyramidActor.GetProperty().SetDiffuseColor(1, 0, 1)
        ren.AddActor(aPixelActor);aPixelActor.GetProperty().SetDiffuseColor(0, 1, 1)
        ren.AddActor(aQuadActor);aQuadActor.GetProperty().SetDiffuseColor(1, 0, 1)
        ren.AddActor(aTriangleActor);aTriangleActor.GetProperty().SetDiffuseColor(.3, 1, .5)
        ren.AddActor(aPolygonActor);aPolygonActor.GetProperty().SetDiffuseColor(1, .4, .5)
        ren.AddActor(aTriangleStripActor);aTriangleStripActor.GetProperty().SetDiffuseColor(.3, .7, 1)
        ren.AddActor(aLineActor);aLineActor.GetProperty().SetDiffuseColor(.2, 1, 1)
        ren.AddActor(aPolyLineActor);aPolyLineActor.GetProperty().SetDiffuseColor(1, 1, 1)
        ren.AddActor(aVertexActor);aVertexActor.GetProperty().SetDiffuseColor(1, 1, 1)
        ren.AddActor(aPolyVertexActor);aPolyVertexActor.GetProperty().SetDiffuseColor(1, 1, 1)
        ren.AddActor(aPentaActor);aPentaActor.GetProperty().SetDiffuseColor(.2, .4, .7)
        ren.AddActor(aHexaActor);aHexaActor.GetProperty().SetDiffuseColor(.7, .5, 1)

        aRIBLight = vtkRIBLight()
        aRIBLight.SetIntensity(0.7)

        ren.AddLight(aRIBLight)
        aLight = vtkLight()

        aLight.PositionalOn()
        aLight.SetConeAngle(10.0)
        aLight.SetIntensity(0.7)
        ren.AddLight(aLight)

        ren.ResetCamera()
        ren.GetActiveCamera().Azimuth(30)
        ren.GetActiveCamera().Elevation(20)
        ren.GetActiveCamera().Dolly(2.8)
        ren.ResetCameraClippingRange()

        dir = VTK_TEMP_DIR

        atext = vtkTexture()
        pnmReader = vtkBMPReader()
        pnmReader.SetFileName(VTK_DATA_ROOT + "/Data/masonry.bmp")
        atext.SetInputConnection(pnmReader.GetOutputPort())
        atext.InterpolateOff()
        aTriangleActor.SetTexture(atext)

        aRIBLight.SetFocalPoint(ren.GetActiveCamera().GetFocalPoint())
        aRIBLight.SetPosition(ren.GetActiveCamera().GetPosition())
        aLight.SetFocalPoint(ren.GetActiveCamera().GetFocalPoint())
        aLight.SetPosition(ren.GetActiveCamera().GetPosition())

        # basically have IO/Export ?
        if vtk_has_IOExport:
            rib = vtkRIBExporter()
            rib.SetRenderWindow(renWin)
            rib.SetFilePrefix(dir + '/cells')
            rib.SetTexturePrefix(dir + '/cells')
            rib.Write()

            iv = vtkIVExporter()
            iv.SetRenderWindow(renWin)
            iv.SetFileName(dir + "/cells.iv")
            iv.Write()
            os.remove(dir + '/cells.iv')

            obj = vtkOBJExporter()
            obj.SetRenderWindow(renWin)
            obj.SetFilePrefix(dir + "/cells")
            obj.Write()
            os.remove(dir + '/cells.obj')
            os.remove(dir + '/cells.mtl')

            vrml = vtkVRMLExporter()
            vrml.SetRenderWindow(renWin)
            #vrml.SetStartWrite(vrml.SetFileName(dir + "/cells.wrl"))
            #vrml.SetEndWrite(vrml.SetFileName("/a/acells.wrl"))
            vrml.SetFileName(dir + "/cells.wrl")
            vrml.SetSpeed(5.5)
            vrml.Write()
            os.remove(dir + '/cells.wrl')

            oogl = vtkOOGLExporter()
            oogl.SetRenderWindow(renWin)
            oogl.SetFileName(dir + "/cells.oogl")
            oogl.Write()
            os.remove(dir + '/cells.oogl')

        # the UnRegister calls are because make object is the same as New,
        # and causes memory leaks. (Python does not treat NewInstance the same as New).
        def DeleteCopies():
            bVoxel.UnRegister(None)
            bHexahedron.UnRegister(None)
            bTetra.UnRegister(None)
            bWedge.UnRegister(None)
            bPyramid.UnRegister(None)
            bPixel.UnRegister(None)
            bQuad.UnRegister(None)
            bTriangle.UnRegister(None)
            bPolygon.UnRegister(None)
            bTriangleStrip.UnRegister(None)
            bLine.UnRegister(None)
            bPolyLine.UnRegister(None)
            bVertex.UnRegister(None)
            bPolyVertex.UnRegister(None)
            bPenta.UnRegister(None)
            bHexa.UnRegister(None)


        DeleteCopies()


        # render and interact with data

        renWin.Render()

        img_file = "cells.png"
        vtkmodules.test.Testing.compareImage(iRen.GetRenderWindow(), vtkmodules.test.Testing.getAbsImagePath(img_file))
        vtkmodules.test.Testing.interact()

if __name__ == "__main__":
     vtkmodules.test.Testing.main([(cells, 'test')])



#!/usr/bin/env python
from vtkmodules.vtkFiltersSources import vtkRegularPolygonSource
from vtkmodules.vtkRenderingCore import (
    vtkActor,
    vtkPolyDataMapper,
    vtkRenderWindow,
    vtkRenderWindowInteractor,
    vtkRenderer,
)
import vtkmodules.vtkInteractionStyle
import vtkmodules.vtkRenderingFreeType
import vtkmodules.vtkRenderingOpenGL2
from vtkmodules.util.misc import vtkGetDataRoot
VTK_DATA_ROOT = vtkGetDataRoot()

# Create two polygon sources, one a closed polyline, one a polygon
#
polyline = vtkRegularPolygonSource()
polyline.SetCenter(1,1,1)
polyline.SetRadius(1)
polyline.SetNumberOfSides(12)
polyline.SetNormal(1,2,3)
polyline.GeneratePolylineOn()
polyline.GeneratePolygonOff()
polylineMapper = vtkPolyDataMapper()
polylineMapper.SetInputConnection(polyline.GetOutputPort())
polylineActor = vtkActor()
polylineActor.SetMapper(polylineMapper)
polylineActor.GetProperty().SetColor(0,1,0)
polylineActor.GetProperty().SetAmbient(1)
polygon = vtkRegularPolygonSource()
polygon.SetCenter(3,1,1)
polygon.SetRadius(1)
polygon.SetNumberOfSides(12)
polygon.SetNormal(1,2,3)
polygon.GeneratePolylineOff()
polygon.GeneratePolygonOn()
polygonMapper = vtkPolyDataMapper()
polygonMapper.SetInputConnection(polygon.GetOutputPort())
polygonActor = vtkActor()
polygonActor.SetMapper(polygonMapper)
polygonActor.GetProperty().SetColor(1,0,0)
polygonActor.GetProperty().SetAmbient(1)
# Create the RenderWindow, Renderer and both Actors
#
ren1 = vtkRenderer()
renWin = vtkRenderWindow()
renWin.AddRenderer(ren1)
iren = vtkRenderWindowInteractor()
iren.SetRenderWindow(renWin)
# create room profile# Add the actors to the renderer, set the background and size
#
ren1.AddActor(polylineActor)
ren1.AddActor(polygonActor)
ren1.SetBackground(0,0,0)
renWin.SetSize(200,200)
renWin.Render()
iren.Initialize()
# prevent the tk window from showing up then start the event loop
# --- end of script --



#!/usr/bin/env python
from vtkmodules.vtkCommonCore import vtkFloatArray
from vtkmodules.vtkCommonDataModel import (
    vtkClosestNPointsStrategy,
    vtkImageData,
)
from vtkmodules.vtkCommonMath import vtkRungeKutta4
from vtkmodules.vtkFiltersCore import vtkAppendFilter
from vtkmodules.vtkFiltersFlowPaths import (
    vtkCompositeInterpolatedVelocityField,
    vtkStreamTracer,
)
from vtkmodules.vtkFiltersModeling import vtkOutlineFilter
from vtkmodules.vtkFiltersSources import vtkLineSource
from vtkmodules.vtkRenderingCore import (
    vtkActor,
    vtkPolyDataMapper,
    vtkRenderWindow,
    vtkRenderWindowInteractor,
    vtkRenderer,
)
import vtkmodules.vtkInteractionStyle
import vtkmodules.vtkRenderingFreeType
import vtkmodules.vtkRenderingOpenGL2

# Parameters for controlling the test size
dim = 40
numStreamlines = 50

# Create three volumes of different resolution and butt them together.  This
# tests vtkPointSet::FindCell() on incompatible meshes (hanging and
# duplicate nodes).

spacing = 1.0 / (2.0*dim - 1.0)
v1 = vtkImageData()
v1.SetOrigin(0.0,0,0)
v1.SetDimensions(2*dim,2*dim,2*dim)
v1.SetSpacing(spacing,spacing,spacing)

spacing = 1.0 / (dim - 1.0)
v2 = vtkImageData()
v2.SetOrigin(1.0,0,0)
v2.SetDimensions(dim,dim,dim)
v2.SetSpacing(spacing,spacing,spacing)

spacing = 1.0 / (2.0*dim - 1.0)
v3 = vtkImageData()
v3.SetOrigin(2.0,0,0)
v3.SetDimensions(2*dim,2*dim,2*dim)
v3.SetSpacing(spacing,spacing,spacing)

# Append the volumes together to create an unstructured grid with duplicate
# and hanging points.
append = vtkAppendFilter()
append.AddInputData(v1)
append.AddInputData(v2)
append.AddInputData(v3)
append.MergePointsOff()
append.Update()

# Create a uniform vector field in the x-direction
numPts = append.GetOutput().GetNumberOfPoints()
vectors = vtkFloatArray()
vectors.SetNumberOfComponents(3)
vectors.SetNumberOfTuples(numPts);
for i in range(0,numPts):
    vectors.SetTuple3(i, 1,0,0)

# A hack but it works
append.GetOutput().GetPointData().SetVectors(vectors)

# Outline around appended unstructured grid
outline = vtkOutlineFilter()
outline.SetInputConnection(append.GetOutputPort())

outlineMapper = vtkPolyDataMapper()
outlineMapper.SetInputConnection(outline.GetOutputPort())

outlineActor = vtkActor()
outlineActor.SetMapper(outlineMapper)

# Now create streamlines from a rake of seed points
pt1 = [0.001,0.1,0.5]
pt2 = [0.001,0.9,0.5]
line = vtkLineSource()
line.SetResolution(numStreamlines-1)
line.SetPoint1(pt1)
line.SetPoint2(pt2)
line.Update()

rk4 = vtkRungeKutta4()
strategy = vtkClosestNPointsStrategy()
ivp = vtkCompositeInterpolatedVelocityField()
ivp.SetFindCellStrategy(strategy)

streamer = vtkStreamTracer()
streamer.SetInputConnection(append.GetOutputPort())
streamer.SetSourceConnection(line.GetOutputPort())
streamer.SetMaximumPropagation(10)
streamer.SetInitialIntegrationStep(.2)
streamer.SetIntegrationDirectionToForward()
streamer.SetMinimumIntegrationStep(0.01)
streamer.SetMaximumIntegrationStep(0.5)
streamer.SetTerminalSpeed(1.0e-12)
streamer.SetMaximumError(1.0e-06)
streamer.SetComputeVorticity(0)
streamer.SetIntegrator(rk4)
streamer.SetInterpolatorPrototype(ivp)
streamer.Update()
reasons = streamer.GetOutput().GetCellData().GetArray("ReasonForTermination")
print(reasons.GetValue(0))

strMapper = vtkPolyDataMapper()
strMapper.SetInputConnection(streamer.GetOutputPort())

strActor = vtkActor()
strActor.SetMapper(strMapper)

# rendering
ren = vtkRenderer()
renWin = vtkRenderWindow()
iren = vtkRenderWindowInteractor()
renWin.AddRenderer(ren)
iren.SetRenderWindow(renWin)

ren.AddActor(outlineActor)
ren.AddActor(strActor)
ren.ResetCamera()
ren.GetActiveCamera().Zoom(2)
renWin.SetSize(600, 300)
renWin.Render()

iren.Start()
